@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/aide-aide?lang_cible=ar
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// R
 	'raccourcis' => 'إختصارات الكتابة',
@@ -20,5 +16,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'raccourcis_note' => 'الحواشي',
 	'raccourcis_resume' => 'باختصار',
 	'raccourcis_simple' => 'تصميم مبسط',
-	'raccourcis_tableau' => 'الجداول'
-);
+	'raccourcis_tableau' => 'الجداول',
+];
