@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/aide-aide?lang_cible=fr_tu
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// R
 	'raccourcis' => 'Raccourcis typographiques',
@@ -20,5 +16,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'raccourcis_note' => 'Notes de bas de page',
 	'raccourcis_resume' => 'En résumé',
 	'raccourcis_simple' => 'Mise en forme simple',
-	'raccourcis_tableau' => 'Tableaux'
-);
+	'raccourcis_tableau' => 'Tableaux',
+];
