@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-aide?lang_cible=es
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'aide_description' => 'Este plugin permite que SPIP incluya ayuda contextual marcada con un icono. Esta ayuda también se puede extender a los plugins.',
 	'aide_nom' => 'Ayuda SPIP',
-	'aide_slogan' => 'Ayuda en línea de SPIP'
-);
+	'aide_slogan' => 'Ayuda en línea de SPIP',
+];
