@@ -226,12 +226,6 @@ function balise_FORMULAIRE__contexte($form, $args) {
 	// charger peut passer une action si le formulaire ne tourne pas sur self()
 	// ou une action vide si elle ne sert pas
 	$action = $valeurs['action'] ?? self('&amp;', true);
-	// bug IEx : si action finit par /
-	// IE croit que le <form ... action=../ > est autoferme
-	if (substr($action, -1) == '/') {
-		// on ajoute une ancre pour feinter IE, au pire ca tue l'ancre qui finit par un /
-		$action .= '#';
-	}
 
 	// recuperer la saisie en cours si erreurs
 	// seulement si c'est ce formulaire qui est poste
@@ -268,8 +262,8 @@ function balise_FORMULAIRE__contexte($form, $args) {
 		$securiser_action = charger_fonction('securiser_action', 'inc');
 		$secu = $securiser_action(reset($valeurs['_action']), end($valeurs['_action']), '', -1);
 		$valeurs['_hidden'] = (isset($valeurs['_hidden']) ? $valeurs['_hidden'] : '') .
-			"<input type='hidden' name='arg' value='" . $secu['arg'] . "' />"
-			. "<input type='hidden' name='hash' value='" . $secu['hash'] . "' />";
+			"<input type='hidden' name='arg' value='" . $secu['arg'] . "'>"
+			. "<input type='hidden' name='hash' value='" . $secu['hash'] . "'>";
 	}
 	*/
 
