@@ -7,7 +7,6 @@
  *  Arnaud Martin, Antoine Pitrou, Philippe Rivière, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.     *
- *  Pour plus de détails voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
 /**
@@ -40,8 +39,8 @@ function base_determine_autoinc($table, $desc = []) {
 	} else {
 		// essayer de faire au mieux !
 		$autoinc = (isset($desc['key']['PRIMARY KEY'])
-			and strpos($desc['key']['PRIMARY KEY'], ',') === false
-			and strpos($desc['field'][$desc['key']['PRIMARY KEY']], 'default') === false);
+			and !str_contains($desc['key']['PRIMARY KEY'], ',')
+			and !str_contains($desc['field'][$desc['key']['PRIMARY KEY']], 'default'));
 	}
 
 	return $autoinc;
