@@ -146,7 +146,7 @@ function calculer_balise_BIGUP_TOKEN($champ, $multiple, $form, $form_args) {
 			$champ = $champ . '[]';
 		}
 	}
-
+	include_spip('inc/Bigup/Identifier');
 	return (new Identifier($form, $form_args))->generer_token_champ($champ);
 }
 
@@ -240,10 +240,16 @@ function bigup_name2nom($name) {
 /**
  * Retourne la liste des mimes types acceptés pour des logos / illustrations,
  * tels qu’attendus par le champ accept.
+ * @param array{objet: string, id_objet: int} $args
  * @return string
  */
-function bigup_get_accept_logos() {
-	$extensions = $GLOBALS['formats_logos'];
+function bigup_get_accept_logos(array $args = []) {
+	include_spip('inc/filtres_images_lib_mini');
+	if (function_exists('_image_extensions_logos')) {
+		$extensions = _image_extensions_logos($args);
+	} else {
+		$extensions = $GLOBALS['formats_logos'];
+	}
 	$mimes = array_map('bigup_get_mime_type_extension', $extensions);
 	return implode(',', $mimes);
 }
