@@ -58,7 +58,12 @@ function bigup_insert_head($flux) {
 function bigup_config():array {
 	include_spip('inc/config');
 	$maxFileSize = intval(lire_config('bigup/max_file_size', 0));
-	$formatLogos = $GLOBALS['formats_logos'];
+	include_spip('inc/filtres_images_lib_mini');
+	if (function_exists('_image_extensions_logos')) {
+		$formatLogos = _image_extensions_logos();
+	} else {
+		$formatLogos = $GLOBALS['formats_logos'];
+	}
 	if (defined('_IMG_MAX_WIDTH') or defined('_IMG_MAX_HEIGHT')) {
 		$clientWidth   = defined('_IMG_MAX_WIDTH') ? (int) _IMG_MAX_WIDTH : 0;
 		$clientHeight  = defined('_IMG_MAX_HEIGHT') ? (int) _IMG_MAX_HEIGHT : 0;
@@ -393,7 +398,12 @@ function inc_bigup_medias_formulaire_illustrer_document_dist($args, $formulaire)
  */
 function inc_bigup_medias_formulaire_editer_logo_dist($args, $formulaire) {
 	$options = [
-		'accept' => bigup_get_accept_logos(),
+		'accept' => bigup_get_accept_logos(
+			[
+				'objet' => $args['contexte']['objet'],
+				'id_objet' => $args['contexte']['id_objet']
+			]
+		),
 		'previsualiser' => true,
 		'input_class' => 'bigup_logo',
 	];
