@@ -141,6 +141,7 @@ function Bigup(params, opts, callbacks) {
 	this.formulaire_action = params.formulaire_action;
 	this.formulaire_action_args = params.formulaire_action_args;
 	this.token = params.token;
+	this.uploadsCount = 0;
 
 	this.target = $.enlever_ancre(this.form.attr('action'));
 	this.name = this.input.attr('name');
@@ -423,6 +424,7 @@ Bigup.prototype = {
 					}
 				});
 				me.progress.retirer(file.emplacement.find('progress'));
+				me.uploadsCount++;
 				me.input.trigger('bigup.fileSuccess', [file, desc]);
 			} catch (e) {
 				desc = _T('bigup:erreur_de_transfert') + ' : ' + e;
@@ -446,7 +448,9 @@ Bigup.prototype = {
 		// qui se déclenche quand tous les upload sont terminés
 		this.flow.on('complete', function () {
 			//console.log("uploads Completed");
-			me.input.trigger('bigup.complete');
+			me.input.trigger('bigup.complete', [ {count: me.uploadsCount} ]);
+			// Réinitialiser le décompte des documents uploadés
+			me.uploadsCount = 0;
 		});
 
 		// Erreur, pas de bol !
