@@ -7,13 +7,12 @@
  *  Arnaud Martin, Antoine Pitrou, Philippe Rivière, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.     *
- *  Pour plus de détails voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
 /**
- * Déclaration des correspondances entre charsets iso-8859-15 et unicode
+ * Déclaration des correspondances entre charsets iso-8859-9 (Turc) et unicode
  *
- * @author Gaetan Ryckeboer <gryckeboer@virtual-net.fr>
+ * @author <alexis@nds.k12.tr>
  *
  * @package SPIP\Core\Charsets
  **/
@@ -25,13 +24,11 @@ if (!defined('_ECRIRE_INC_VERSION')) {
 load_charset('iso-8859-1');
 
 $trans = $GLOBALS['CHARSET']['iso-8859-1'];
-$trans[164] = 8364;
-$trans[166] = 352;
-$trans[168] = 353;
-$trans[180] = 381;
-$trans[184] = 382;
-$trans[188] = 338;
-$trans[189] = 339;
-$trans[190] = 376;
+$trans[240] = 287; //gbreve
+$trans[208] = 286; //Gbreve
+$trans[221] = 304; //Idot
+$trans[253] = 305; //inodot
+$trans[254] = 351; //scedil
+$trans[222] = 350; //Scedil
 
-$GLOBALS['CHARSET']['iso-8859-15'] = $trans;
+$GLOBALS['CHARSET']['iso-8859-9'] = $trans;
