@@ -48,7 +48,7 @@ function compagnon_compagnon_messages($flux) {
 						'titre' => _T('compagnon:c_accueil_configurer_site'),
 						'texte' => _T('compagnon:c_accueil_configurer_site_texte', ['nom' => $nom]),
 						'statuts' => ['webmestre'],
-						'target' => '#bando_identite .nom_site_spip .nom',
+						'target' => '#bando1_menu_configuration',
 					];
 					$aides[] = [
 						'id' => 'accueil_publication',
