@@ -133,7 +133,7 @@ function compagnonage($flux, $pipeline) {
 	if ($ajouts) {
 		$twinkle = find_in_path('prive/javascript/jquery.twinkle.js');
 		$ajouts .= <<<JS
-<script type="text/javascript">
+<script>
 jQuery.getScript('$twinkle',function(){
 	jQuery(function(){
 		var options = {
