@@ -1,15 +1,12 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
 // Fichier source, a modifier dans https://git.spip.net/spip/compagnon.git
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
 
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compagnon_description' => 'Le compagnon offre une aide aux utilisateurs
 		lors de leur première visite dans l’espace privé de SPIP.',
 	'compagnon_nom' => 'Compagnon',
-	'compagnon_slogan' => 'Assistant de premiers pas avec SPIP'
-);
+	'compagnon_slogan' => 'Assistant de premiers pas avec SPIP',
+];
