@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=hac
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compagnon_description' => 'کەسی هامڕا چە یەکەمین سەردانیکەردەو نۋیسنگاو پەشتۊSPIP .خزمەتو بەکاربەرا کەرۊ',
 	'compagnon_nom' => 'ھامڕا',
-	'compagnon_slogan' => 'ڕانیشاندەرو یەکەمین ھەنگامەکا چنی SPIP'
-);
+	'compagnon_slogan' => 'ڕانیشاندەرو یەکەمین ھەنگامەکا چنی SPIP',
+];
