@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/compresseur?lang_cible=ca
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// I
 	'info_compresseur_titre' => 'Optimitzacions i compressió',
@@ -17,5 +13,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// T
 	'texte_compacter_avertissement' => 'Estigueu alerta de no activar aquestes opcions durant el desenvolupament del vostre lloc: els elements compactats perdent tota llegibilitat. ',
 	'texte_compacter_script_css' => 'SPIP pot compactar els scripts javascript i els fulls d’estil CSS, per enregistrar-los a dins dels fitxers estàtics; això accelera la presentació del lloc Web.',
-	'titre_compacter_script_css' => 'Compressió dels scripts i el CSS'
-);
+	'titre_compacter_script_css' => 'Compressió dels scripts i el CSS',
+];
