@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/compresseur?lang_cible=fa
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// I
 	'info_compresseur_titre' => 'بهينه‌سازي و فشرده سازي',
@@ -19,5 +15,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// T
 	'texte_compacter_avertissement' => 'در جريان توسعه‌ي سايت خود مراقب باشيد اين گزينه‌ها را فعال نسازيد:‌ خطازدايي از عناصر فشرده شده دشوار مي‌‌شود.',
 	'texte_compacter_script_css' => 'اسپيپ مي‌تواند فايل‌هاي جاواسكريپت و شيوه‌برگه‌هاي سي.اس.اس را فشرده كرده و در فال‌هاي استاتيك صبط كند. اين كار نمايش سايت را تسريع خواهد كرد. ',
-	'titre_compacter_script_css' => 'فشرده‌سازي نويسه‌ها و سي.اس.اس'
-);
+	'titre_compacter_script_css' => 'فشرده‌سازي نويسه‌ها و سي.اس.اس',
+];
