@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/compresseur?lang_cible=lb
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// I
 	'info_compresseur_titre' => 'Optimisatioun a Kompressioun',
@@ -19,5 +15,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// T
 	'texte_compacter_avertissement' => 'Schalt dës Optiounen net während der Entwécklung vum Site an: déi kompriméiert Elementer si net einfach liesbar.',
 	'texte_compacter_script_css' => 'SPIP ka Javascript oder CSS Style-Sheets kompriméieren an als statesch Dokumenter späicheren; da ginn d’Säite vum Site méi séier gewisen.',
-	'titre_compacter_script_css' => 'Skripten an CSS kompriméieren'
-);
+	'titre_compacter_script_css' => 'Skripten an CSS kompriméieren',
+];
