@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/compresseur?lang_cible=sk
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// E
 	'explication_url_statique_ressources' => 'URL, ktorá môže obslúžiť statické súbory (obrázky, JS...) bez cookie. Obyčajne je to alternatívna subdoména, ktorá aj odkazuje na stránku.',
@@ -26,5 +22,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// T
 	'texte_compacter_avertissement' => 'Dajte si pozor na to, aby ste tieto možnosti nenastavili počas vývoja svojej stránky, lebo kompaktné prvky sa stanú nečitateľné.',
 	'texte_compacter_script_css' => 'SPIP dokáže zmenšiť Javascriptove súbory a súbory so štýlmi a uložiť ich ako statické súbory. Tak zrýchľuje zobrazenie stránky.',
-	'titre_compacter_script_css' => 'Kompresia skriptov a CSS'
-);
+	'titre_compacter_script_css' => 'Kompresia skriptov a CSS',
+];
