@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compresseur?lang_cible=br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compresseur_description' => 'Gwaskadurez css ha javascript en titouroù ar pajennoù html deus <code>ecrire/</code> ha/pe deus al lec’h publik',
-	'compresseur_slogan' => 'Gwaskadurezh css ha javascript'
-);
+	'compresseur_slogan' => 'Gwaskadurezh css ha javascript',
+];
