@@ -1,13 +1,10 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
 // Fichier source, a modifier dans https://git.spip.net/spip/compresseur.git
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
 
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compresseur_description' => 'Compression des css et javascript dans l’en-tête des pages html de <code>ecrire/</code> et/ou du site public',
-	'compresseur_slogan' => 'Compression des css et javascript'
-);
+	'compresseur_slogan' => 'Compression des css et javascript',
+];
