@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compresseur?lang_cible=oc_ni_mis
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// C
 	'compresseur_description' => 'Coumpressioun dei css e javascript en la prima-testa dei pàgina html de <code>ecrire/</code> e/o dóu sit pùblicou',
-	'compresseur_slogan' => 'Coumpressioun dei css e javascript'
-);
+	'compresseur_slogan' => 'Coumpressioun dei css e javascript',
+];
