@@ -141,6 +141,9 @@ class JavaScriptPacker {
 		// protect strings
 		$parser->add('/\'[^\'\\n\\r]*\'/',$this->IGNORE);
 		$parser->add('/"[^"\\n\\r]*"/', $this->IGNORE);
+		// protect template strings, at least the one without \n
+		// if we don't add this limit, it can takes the entire file from a closing tick in comments
+		$parser->add('/`[^`\\n\\r]*`/', $this->IGNORE);
 		// remove comments
 		if (!$this->PHP_ISSUE_81101) {
 			$parser->add('/\\/\\/[^\\n\\r]*[\\n\\r]/', "\n");
