@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dump?lang_cible=br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// D
 	'dump_description' => 'Gwared hag assevel deus an diaz titouroù e SQLite ',
-	'dump_slogan' => 'Gwared hag assevel deus an diaz titouroù SPIP'
-);
+	'dump_slogan' => 'Gwared hag assevel deus an diaz titouroù SPIP',
+];
