@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dump?lang_cible=fr_fem
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// D
 	'dump_description' => 'Sauvegarde de la base de données en SQLite et restauration',
-	'dump_slogan' => 'Sauvegarde et restauration de la base de données SPIP'
-);
+	'dump_slogan' => 'Sauvegarde et restauration de la base de données SPIP',
+];
