@@ -3,13 +3,9 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-images?lang_cible=ja
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// I
 	'images_description' => '画像および色変換フィルタ',
-	'images_slogan' => '画像および色変換フィルタ'
-);
+	'images_slogan' => '画像および色変換フィルタ',
+];
