@@ -11,7 +11,7 @@ return [
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'pa tolos artículos, menos los que tengan el foru desactiváu.',
 	'bouton_radio_enregistrement_obligatoire' => 'Rexistru obligatoriu (los usuarios
   tienen que abonase coles sos señes d’e-mail enantes
-  de que puedan escribir les sos contribuciones).',
+  de que puedan escribir les sos contribuciones).', # MODIF
 	'bouton_radio_moderation_priori' => 'Moderación a priori (les contribuciones
  nun apaecerán en públicu hasta que les validen
  los alministradores).', # MODIF
@@ -20,7 +20,7 @@ return [
 	'bouton_radio_modere_priori' => 'moderación a priori',
 	'bouton_radio_publication_immediate' => 'Espublizar d’inmediatu los mensaxes
  (les contribuciones s’amuesen desque s’unvíen, los alministradores pueden
- desaniciales llueu).',
+ desaniciales llueu).', # MODIF
 
 	// D
 	'documents_interdits_forum' => 'Documentos torgaos nel foru',
@@ -66,13 +66,13 @@ return [
  de moderación por omisión:</i>', # MODIF
 	'info_appliquer_choix_moderation' => 'Aplicar esta escoyeta pal llendamientu:',
 	'info_config_forums_prive' => 'Nel espaciu priváu del sitiu, puedes activar dellos tipos de foros:', # MODIF
-	'info_config_forums_prive_admin' => 'Un foru acutáu pa los alministradores del sitiu:',
-	'info_config_forums_prive_global' => 'Un foru global, abiertu pa tolos redactores:',
+	'info_config_forums_prive_admin' => 'Un foru acutáu pa los alministradores del sitiu:', # MODIF
+	'info_config_forums_prive_global' => 'Un foru global, abiertu pa tolos redactores:', # MODIF
 	'info_config_forums_prive_objets' => 'Un foru pa cada artículu, breve, sitiu referenciáu, etc.:',
 	'info_desactiver_forum_public' => 'Desactivar l’usu de los foros publicos.
  Los foros públicos podrán autorizase casu por casu
  pa los artículos; pero tarán torgaos pa les estayes, breves, etc.',
-	'info_envoi_forum' => 'Unvíu de los foros a los autores de los artículos',
+	'info_envoi_forum' => 'Unvíu de los foros a los autores de los artículos', # MODIF
 	'info_fonctionnement_forum' => 'Funcionamientu del foru:',
 	'info_gauche_suivi_forum_2' => 'La páxina de <i>siguimientu de los foros</i> ye una ferramienta de xestión del sitiu Web (y non un espaciu pal discutiniu o la redaición). Amuesa toles contribuciones de los foros del sitiu, lo mesmo de la parte pública que del espaciu priváu y te permite remanar eses contribuciones.', # MODIF
 	'info_liens_syndiques_3' => 'foros',
@@ -81,15 +81,15 @@ return [
 	'info_liens_syndiques_6' => 'ta',
 	'info_liens_syndiques_7' => 'esperando pola validación',
 	'info_mode_fonctionnement_defaut_forum_public' => 'Mou de funcionamientu por omisión de los foros públicos',
-	'info_option_email' => 'Cuando un visitante del sitiu unvía un mensaxe nuevu al foru venceyáu a un artículu, puede avisase a los o les autores del mesmu por e-mail. Escoyer pa cada tipu de foru si va emplegase esta opción.',
+	'info_option_email' => 'Cuando un visitante del sitiu unvía un mensaxe nuevu al foru venceyáu a un artículu, puede avisase a los o les autores del mesmu por e-mail. Escoyer pa cada tipu de foru si va emplegase esta opción.', # MODIF
 	'info_pas_de_forum' => 'ensin foru',
 	'info_question_visiteur_ajout_document_forum' => 'Si quiés autorizar que los visitantes amesten documentos (imáxenes, sones...) nos sos mensaxes del foru, indica embaxo la llista d’estensiones de documentu permitíes nos foros (p. ex: gif, jpg, png, mp3).', # MODIF
 	'info_question_visiteur_ajout_document_forum_format' => 'Si quiés autorizar tolos tipos de documentu que SPIP considera fiables, pon un asteriscu. Pa nun autorizar na, déxalo en blancu,', # MODIF
-	'item_activer_forum_administrateur' => 'Activar el foru de los alministradores',
-	'item_config_forums_prive_global' => 'Activar el foru de los redactores',
+	'item_activer_forum_administrateur' => 'Activar el foru de los alministradores', # MODIF
+	'item_config_forums_prive_global' => 'Activar el foru de los redactores', # MODIF
 	'item_config_forums_prive_objets' => 'Activar estos foros',
-	'item_desactiver_forum_administrateur' => 'Desactivar el foru de los alministradores',
-	'item_non_config_forums_prive_global' => 'Desactivar el foru de los redactores',
+	'item_desactiver_forum_administrateur' => 'Desactivar el foru de los alministradores', # MODIF
+	'item_non_config_forums_prive_global' => 'Desactivar el foru de los redactores', # MODIF
 	'item_non_config_forums_prive_objets' => 'Desactivar estos foros',
 
 	// L
@@ -112,7 +112,7 @@ return [
 	// T
 	'text_article_propose_publication_forum' => 'Encamentamoste a dar la to opinión nel foru axuntu a esti artículu (embaxo de la páxina).',
 	'texte_en_cours_validation_forum' => 'Encamentámoste que opines usando los foros que tien xuníos.',
-	'titre_cadre_forum_administrateur' => 'Foru privau de los alministradores',
+	'titre_cadre_forum_administrateur' => 'Foru privau de los alministradores', # MODIF
 	'titre_cadre_forum_interne' => 'Foru internu',
 	'titre_config_forums_prive' => 'Foros de l’espaciu priváu',
 	'titre_forum' => 'Foru',
