@@ -9,7 +9,7 @@ return [
 	'bouton_radio_articles_futurs' => 'pouze k budoucím článkům (žádná akce v databázi).',
 	'bouton_radio_articles_tous' => 'ke všem článkům bez výjimky.',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'ke všem článkům s výjimkou těch, kde je vypnutá diskusní skupina.',
-	'bouton_radio_enregistrement_obligatoire' => 'Povinná registrace (uživatelé se musí nejprve přihlásit zadáním své elektronické adresy a teprve potom mohou zasílat své příspěvky).',
+	'bouton_radio_enregistrement_obligatoire' => 'Povinná registrace (uživatelé se musí nejprve přihlásit zadáním své elektronické adresy a teprve potom mohou zasílat své příspěvky).', # MODIF
 	'bouton_radio_moderation_priori' => 'Moderovaná skupina (příspěvky
  budou zveřejněny až po schválení jedním
  ze správců).', # MODIF
@@ -18,7 +18,7 @@ return [
 	'bouton_radio_modere_priori' => 'moderování předem', # MODIF
 	'bouton_radio_publication_immediate' => 'Okamžité zveřejňování zpráv
  (příspěvky se zobrazují okamžitě,
- správci je mohou odstranit dodatečně).',
+ správci je mohou odstranit dodatečně).', # MODIF
 
 	// D
 	'documents_interdits_forum' => 'Dokumenty jsou ve fóru zakázané',
@@ -66,7 +66,7 @@ return [
 	'info_desactiver_forum_public' => 'Vypnout veřejné diskusní skupiny
 . Tyto skupiny bude možno zapnout ad hoc
  u jednotlivých článků; budou zakázány u sekcí, novinek atd.',
-	'info_envoi_forum' => 'Zasílání diskusních skupin autorům článků',
+	'info_envoi_forum' => 'Zasílání diskusních skupin autorům článků', # MODIF
 	'info_fonctionnement_forum' => 'Fungování diskusní skupiny:',
 	'info_gauche_suivi_forum_2' => 'Stránka pro <i>sledování diskusních skupin</i> je určena ke správě vašeho webu (nejedná se o prostor pro diskusi ani pro redigování). Jsou na ní zobrazeny všechny diskusní příspěvky z veřejné skupiny a umožňuje vám jejich správu.', # MODIF
 	'info_liens_syndiques_3' => 'diskusní skupiny',
@@ -79,8 +79,8 @@ return [
   webu poslali zprávu do diskusní skupiny, týkající se
   jejich článku. Chcete tuto možnost použít?', # MODIF
 	'info_pas_de_forum' => 'bez diskusní skupiny',
-	'item_activer_forum_administrateur' => 'Zapnout diskusní skupinu správců',
-	'item_desactiver_forum_administrateur' => 'Vypnout diskusní skupinu správců',
+	'item_activer_forum_administrateur' => 'Zapnout diskusní skupinu správců', # MODIF
+	'item_desactiver_forum_administrateur' => 'Vypnout diskusní skupinu správců', # MODIF
 
 	// L
 	'lien_reponse_article' => 'Odpověď na článek',
@@ -97,7 +97,7 @@ return [
 	'repondre_message' => 'Reagovat na tuto zprávu',
 
 	// T
-	'titre_cadre_forum_administrateur' => 'Soukromá diskusní skupina správců',
+	'titre_cadre_forum_administrateur' => 'Soukromá diskusní skupina správců', # MODIF
 	'titre_cadre_forum_interne' => 'Interní diskusní skupina',
 	'titre_forum' => 'Diskusní skupina',
 	'titre_forum_suivi' => 'Sledování diskusních skupin',
