@@ -12,13 +12,13 @@ return [
 	'bouton_radio_articles_futurs' => ' ( منحصرأ براى مقالات آينده (بر روى  داده پى ها بى تأثير ميباشد',
 	'bouton_radio_articles_tous' => 'به تمامى مقاله ها، بدون استثناء',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'به تمامى مقاله ها، بجز آنهائى كه سخنگاهشان غير فعال است. ',
-	'bouton_radio_enregistrement_obligatoire' => 'ضبط اجبارى، (كاربران بايد, براى داشتن آدرس الكترونيكى  مشترك شوند تا بتوانند پيامهايشان را پست كنند)      ',
-	'bouton_radio_moderation_priori' => 'تعديل از پيش (نوشته‌ها پيش از تأييد مديران منتشر نمي‌شوند).',
+	'bouton_radio_enregistrement_obligatoire' => 'ضبط اجبارى، (كاربران بايد, براى داشتن آدرس الكترونيكى  مشترك شوند تا بتوانند پيامهايشان را پست كنند)      ', # MODIF
+	'bouton_radio_moderation_priori' => 'تعديل از پيش (نوشته‌ها پيش از تأييد مديران منتشر نمي‌شوند).', # MODIF
 	'bouton_radio_modere_abonnement' => 'براى مشتركين',
 	'bouton_radio_modere_posteriori' => 'تعديل بعدي ',
 	'bouton_radio_modere_priori' => 'تعديل از پيش',
 	'bouton_radio_publication_immediate' => 'انتشار فورى پيامها 
- (پيامها بمحض فرستاده شدن نمايان ميشوند سپس گردانند گان سايت ميتوانند آنها را حذف كنند)',
+ (پيامها بمحض فرستاده شدن نمايان ميشوند سپس گردانند گان سايت ميتوانند آنها را حذف كنند)', # MODIF
 
 	// D
 	'documents_interdits_forum' => 'سندهاي ممنوع در سخناگاه ',
@@ -38,7 +38,7 @@ return [
 	'forum_avez_selectionne' => ': شما انتخاب كرده ايد',
 	'forum_cliquer_retour' => ' </a> اينجا <a href=\'@retour_forum@\'>     را براى ادامه كليك كنيد     ',
 	'forum_forum' => 'سخنگاه',
-	'forum_info_modere' => 'اين سخنگاه از پيش تعديل مي‌شود: نظر شما پيش از تأييد مديران سايت ظاهر نخواهد شد.',
+	'forum_info_modere' => 'اين سخنگاه از پيش تعديل مي‌شود: نظر شما پيش از تأييد مديران سايت ظاهر نخواهد شد.', # MODIF
 	'forum_lien_hyper' => ' پيوند هايپرتكست  ',
 	'forum_message' => 'پيام شما',
 	'forum_message_definitif' => 'پيام نهايى : به سايت بفرستيد',
@@ -75,11 +75,11 @@ return [
 	'info_activer_forum_public' => ' براى فعال كردن سخنگاه همگانى، خواهشمند است شيوه تعديل پيش‌گزيده را انتخاب كنيد:',
 	'info_appliquer_choix_moderation' => ': اين انتخاب معتدل را بكار بريد',
 	'info_config_forums_prive' => 'در قسمت شخصي سايت مي‌توانيد چند نوع سخنگاه را فعال كنيد:',
-	'info_config_forums_prive_admin' => 'يك سخنگاه اختصاصي براي مديران سايت:',
-	'info_config_forums_prive_global' => 'يك سخنگاه‌ي كلي، گشوده به روي تمام نويسندگان:',
+	'info_config_forums_prive_admin' => 'يك سخنگاه اختصاصي براي مديران سايت:', # MODIF
+	'info_config_forums_prive_global' => 'يك سخنگاه‌ي كلي، گشوده به روي تمام نويسندگان:', # MODIF
 	'info_config_forums_prive_objets' => 'يك سخناگاه براي هر مقاله، خبر و سايت‌ ارجاعي و غيره:',
 	'info_desactiver_forum_public' => 'استفاده از سخنگاه همگانى را غير فعال كنيد. استفاده از آن ميتواند مورد به مورد درباره مقالات داده شود، ولى در موارد ديگر ممنوع خواهد بود',
-	'info_envoi_forum' => 'ارسال سخنگاه به نويسند گان مقاله ها',
+	'info_envoi_forum' => 'ارسال سخنگاه به نويسند گان مقاله ها', # MODIF
 	'info_fonctionnement_forum' => ': عملكرد سخنگاه',
 	'info_forums_liees_mot' => 'پيام‌هاي سخنگاه مربوط به اين واژه',
 	'info_gauche_suivi_forum_2' => 'صفحه<i> پيگيري سخنگاه‌ها </i> ابزار اداره سايت (و نه مكانى براى بحث يا نگارش) شماست. اين صفحه، امكان اعلان تمام پيامهاى سخنگاه همگانى و خصوصى و همچنين اداره پيامها را بشما ميدهد.',
@@ -92,17 +92,17 @@ return [
 	'info_liens_titre' => 'پيوند‌(هاي) محتوا(ها) در تيتر پيام',
 	'info_mode_fonctionnement_defaut_forum_public' => 'طرز عملكرد سخنگاه هاى عمومى',
 	'info_nb_messages_forum' => '@nb@ پيام از سخنگاه',
-	'info_option_email' => 'هنگاميكه يكى از بينند گان سايت پيامى در سخنگاه راجع به مقاله‌اى مي‌فرستد، نويسند گان مقاله  مي‌توانند از آن آگاه شوند. آيا مي‌خواهيد اين گزينه را داشته باشيد؟',
+	'info_option_email' => 'هنگاميكه يكى از بينند گان سايت پيامى در سخنگاه راجع به مقاله‌اى مي‌فرستد، نويسند گان مقاله  مي‌توانند از آن آگاه شوند. آيا مي‌خواهيد اين گزينه را داشته باشيد؟', # MODIF
 	'info_pas_de_forum' => 'بدون سخنگاه',
-	'info_question_visiteur_ajout_document_forum' => 'اگر مايليد به بازديد‌كنندگان اجازه دهيد كه سند‌هايي (تصوير، صدا و . . . ) را به پيام‌هايشان در سخنگاه بچسبانند، فهرست توسعه‌هاي مجاز براي سند‌ها را براي سخنگاه‌ها، در زير، مشخص كنيد (ex: gif, jpg, png, mp3).',
+	'info_question_visiteur_ajout_document_forum' => 'اگر مايليد به بازديد‌كنندگان اجازه دهيد كه سند‌هايي (تصوير، صدا و . . . ) را به پيام‌هايشان در سخنگاه بچسبانند، فهرست توسعه‌هاي مجاز براي سند‌ها را براي سخنگاه‌ها، در زير، مشخص كنيد (ex: gif, jpg, png, mp3).', # MODIF
 	'info_question_visiteur_ajout_document_forum_format' => 'اگر مايليد به تمام انواع سند‌هايي كه با اسپيپ منطبق است اجازه بدهيد، يك ستاره بگذاريد. اگر اجازه نمي‌دهيد هيچ كار نكنيد.',
 	'interface_formulaire' => 'فرم ميانجي',
 	'interface_onglets' => 'فرم‌ها با تب‌ها',
-	'item_activer_forum_administrateur' => 'سخنگاه گردانندگان سايت را فعال كنيد',
-	'item_config_forums_prive_global' => 'فعال سازي سخنگاه نويسندگان',
+	'item_activer_forum_administrateur' => 'سخنگاه گردانندگان سايت را فعال كنيد', # MODIF
+	'item_config_forums_prive_global' => 'فعال سازي سخنگاه نويسندگان', # MODIF
 	'item_config_forums_prive_objets' => 'فعال سازي اين سخنگاه‌ها',
-	'item_desactiver_forum_administrateur' => 'سخنگاه گردانندگان سايت را غير فعال كنيد',
-	'item_non_config_forums_prive_global' => 'غيرفعال سازي سخنگاه نويسندگان',
+	'item_desactiver_forum_administrateur' => 'سخنگاه گردانندگان سايت را غير فعال كنيد', # MODIF
+	'item_non_config_forums_prive_global' => 'غيرفعال سازي سخنگاه نويسندگان', # MODIF
 	'item_non_config_forums_prive_objets' => 'غيرفعال سازي اين سخنگاه‌ها',
 
 	// L
@@ -114,12 +114,12 @@ return [
 
 	// M
 	'messages_aucun' => 'هيچ',
-	'messages_meme_auteur' => 'تمام پيام‌هاي اين نويسنده',
+	'messages_meme_auteur' => 'تمام پيام‌هاي اين نويسنده', # MODIF
 	'messages_meme_email' => 'تمام پيام‌هاي اين ايميل',
 	'messages_meme_ip' => 'تمام پيام‌هاي اين آي.پي',
 	'messages_off' => 'حذفي‌ها',
 	'messages_perso' => 'اشخاص',
-	'messages_privadm' => 'ادمين‌ها',
+	'messages_privadm' => 'ادمين‌ها', # MODIF
 	'messages_prive' => 'خصوصي',
 	'messages_privoff' => 'حذفي‌ها',
 	'messages_privrac' => 'همگاني‌ها',
@@ -148,7 +148,7 @@ return [
 	'texte_en_cours_validation' => 'مطالب زير منتظر تأييد‌اند',
 	'texte_en_cours_validation_forum' => 'مي‌توانيد از طريق سخنگاه‌هاي پيوست شده به‌ آن‌ها نظراتتان را بيان كنيد.',
 	'texte_messages_publics' => 'پيام‌هاي همگاني در مورد:‌',
-	'titre_cadre_forum_administrateur' => 'سخنگاه خصوصى گردانندگان سايت',
+	'titre_cadre_forum_administrateur' => 'سخنگاه خصوصى گردانندگان سايت', # MODIF
 	'titre_cadre_forum_interne' => 'سخنگاه داخلى',
 	'titre_config_forums_prive' => 'سخنگاه‌هاي قسمت شخصي',
 	'titre_forum' => 'سخنگاه',
