@@ -12,14 +12,14 @@ return [
 	'bouton_radio_articles_futurs' => 'aux articles futurs uniquement (pas d’action sur la base de données).',
 	'bouton_radio_articles_tous' => 'à tous les articles sans exception.',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'à tous les articles, sauf ceux dont le forum est désactivé.',
-	'bouton_radio_enregistrement_obligatoire' => 'Enregistrement obligatoire (les utilisateurs doivent s’abonner en fournissant leur adresse email avant de pouvoir poster des contributions).',
-	'bouton_radio_moderation_priori' => 'Modération a priori (les contributions ne s’affichent publiquement qu’après validation par les administrateurs).',
+	'bouton_radio_enregistrement_obligatoire' => 'Enregistrement obligatoire (les utilisateurs doivent s’abonner en fournissant leur adresse email avant de pouvoir poster des contributions).', # MODIF
+	'bouton_radio_moderation_priori' => 'Modération a priori (les contributions ne s’affichent publiquement qu’après validation par les administrateurs).', # MODIF
 	'bouton_radio_modere_abonnement' => 'sur abonnement',
 	'bouton_radio_modere_posteriori' => 'modération a posteriori',
 	'bouton_radio_modere_priori' => 'modération a priori',
 	'bouton_radio_publication_immediate' => 'Publication immédiate des messages
 	(les contributions s’affichent dès leur envoi, les administrateurs peuvent
-	les supprimer ensuite).',
+	les supprimer ensuite).', # MODIF
 
 	// D
 	'documents_interdits_forum' => 'Documents interdits dans le forum',
@@ -42,7 +42,7 @@ return [
 	'forum_cliquer_retour' => 'Clique <a href=\'@retour_forum@\'>ici</a> pour continuer.',
 	'forum_envoyer' => 'Envoyer',
 	'forum_forum' => 'forum',
-	'forum_info_modere' => 'Ce forum est modéré à priori : ta contribution n’apparaîtra qu’après avoir été validée par un administrateur du site.',
+	'forum_info_modere' => 'Ce forum est modéré à priori : ta contribution n’apparaîtra qu’après avoir été validée par un administrateur du site.', # MODIF
 	'forum_lien_hyper' => 'Lien hypertexte',
 	'forum_message' => 'Ton message',
 	'forum_message_definitif' => 'Message définitif : envoyer au site',
@@ -84,13 +84,13 @@ return [
 	'info_activer_forum_public' => 'Pour activer les forums publics, choisis leur mode de modération par défaut :',
 	'info_appliquer_choix_moderation' => 'Appliquer ce choix de modération :',
 	'info_config_forums_prive' => 'Dans l’espace privé du site, tu peux activer plusieurs types de forums :',
-	'info_config_forums_prive_admin' => 'Un forum réservé aux administrateurs du site :',
-	'info_config_forums_prive_global' => 'Un forum global, ouvert à tous les rédacteurs :',
+	'info_config_forums_prive_admin' => 'Un forum réservé aux administrateurs du site :', # MODIF
+	'info_config_forums_prive_global' => 'Un forum global, ouvert à tous les rédacteurs :', # MODIF
 	'info_config_forums_prive_objets' => 'Un forum sous chaque article, brève, site référencé, etc. :',
 	'info_desactiver_forum_public' => 'Désactiver l’utilisation des forums
 	publics. Les forums publics pourront être autorisés au cas par cas
 	sur les articles ; ils seront interdits sur les rubriques, brèves, etc.',
-	'info_envoi_forum' => 'Envoi des forums aux auteurs des articles',
+	'info_envoi_forum' => 'Envoi des forums aux auteurs des articles', # MODIF
 	'info_fonctionnement_forum' => 'Fonctionnement du forum :',
 	'info_forcer_previsualisation_court' => 'Forcer la prévisualisation',
 	'info_forcer_previsualisation_long' => 'Forcer la prévisualisation avant envoi du message',
@@ -105,18 +105,18 @@ return [
 	'info_liens_titre' => 'Lien(s) contenu(s) dans le titre du message',
 	'info_mode_fonctionnement_defaut_forum_public' => 'Mode de fonctionnement par défaut des forums publics',
 	'info_nb_messages_forum' => '@nb@ messages de forum',
-	'info_option_email' => 'Lorsqu’un visiteur du site poste un nouveau message dans le forum associé à un article, les auteurs de l’article peuvent être prévenus de ce message par email. Indiquer pour chaque type de forum s’il faut utiliser cette option.',
+	'info_option_email' => 'Lorsqu’un visiteur du site poste un nouveau message dans le forum associé à un article, les auteurs de l’article peuvent être prévenus de ce message par email. Indiquer pour chaque type de forum s’il faut utiliser cette option.', # MODIF
 	'info_pas_de_forum' => 'pas de forum',
-	'info_question_visiteur_ajout_document_forum' => 'Si tu souhaites autoriser les visiteurs à joindre des documents (images, sons…) à leurs messages de forum, indique ci-dessous la liste des extensions de documents autorisés pour les forums (ex : gif, jpg, png, mp3).',
+	'info_question_visiteur_ajout_document_forum' => 'Si tu souhaites autoriser les visiteurs à joindre des documents (images, sons…) à leurs messages de forum, indique ci-dessous la liste des extensions de documents autorisés pour les forums (ex : gif, jpg, png, mp3).', # MODIF
 	'info_question_visiteur_ajout_document_forum_format' => 'Si tu souhaites autoriser tous les types de documents considérés comme fiables par SPIP, mets une étoile. Pour ne rien autoriser, n’indique rien.',
 	'info_selectionner_message' => 'Sélectionner les messages :',
 	'interface_formulaire' => 'Interface formulaire',
 	'interface_onglets' => 'Interface avec onglets',
-	'item_activer_forum_administrateur' => 'Activer le forum des administrateurs',
-	'item_config_forums_prive_global' => 'Activer le forum des rédacteurs',
+	'item_activer_forum_administrateur' => 'Activer le forum des administrateurs', # MODIF
+	'item_config_forums_prive_global' => 'Activer le forum des rédacteurs', # MODIF
 	'item_config_forums_prive_objets' => 'Activer ces forums',
-	'item_desactiver_forum_administrateur' => 'Désactiver le forum des administrateurs',
-	'item_non_config_forums_prive_global' => 'Désactiver le forum des rédacteurs',
+	'item_desactiver_forum_administrateur' => 'Désactiver le forum des administrateurs', # MODIF
+	'item_non_config_forums_prive_global' => 'Désactiver le forum des rédacteurs', # MODIF
 	'item_non_config_forums_prive_objets' => 'Désactiver ces forums',
 
 	// L
@@ -130,12 +130,12 @@ return [
 
 	// M
 	'messages_aucun' => 'Aucun',
-	'messages_meme_auteur' => 'Tous les messages de cet auteur',
+	'messages_meme_auteur' => 'Tous les messages de cet auteur', # MODIF
 	'messages_meme_email' => 'Tous les messages de cet email',
 	'messages_meme_ip' => 'Tous les messages de cette IP',
 	'messages_off' => 'Supprimés',
 	'messages_perso' => 'Personnels',
-	'messages_privadm' => 'Administrateurs',
+	'messages_privadm' => 'Administrateurs', # MODIF
 	'messages_prive' => 'Privés',
 	'messages_privoff' => 'Supprimés',
 	'messages_privrac' => 'Généraux',
@@ -164,7 +164,7 @@ return [
 	'texte_en_cours_validation' => 'Les articles, brèves, forums ci-dessous sont proposés à la publication.',
 	'texte_en_cours_validation_forum' => 'N’hésite pas à donner ton avis grâce aux forums qui leur sont attachés.',
 	'texte_messages_publics' => 'Messages publics sur :',
-	'titre_cadre_forum_administrateur' => 'Forum privé des administrateurs',
+	'titre_cadre_forum_administrateur' => 'Forum privé des administrateurs', # MODIF
 	'titre_cadre_forum_interne' => 'Forum interne',
 	'titre_config_forums_prive' => 'Forums de l’espace privé',
 	'titre_forum' => 'Forum',
