@@ -11,7 +11,7 @@ return [
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'לכל הכתבות, חוץ מאלה עם הפורומים הפסולים',
 	'bouton_radio_enregistrement_obligatoire' => 'שמירה הכרחית (ה
  משתמשים צריכים להיות מנויים על ידי מסירת כתובת המייל שלהם לפני
- שהם יוכלו לשלוח את תרומותיהם).',
+ שהם יוכלו לשלוח את תרומותיהם).', # MODIF
 	'bouton_radio_moderation_priori' => 'בוררות מוקדמת (ה
  תורמים מופיעים בציבור רק לאחר שהם מאושרים על ידי
  האדמיניסטרטורים).', # MODIF
@@ -20,7 +20,7 @@ return [
 	'bouton_radio_modere_priori' => 'צמצום מראש', # MODIF
 	'bouton_radio_publication_immediate' => 'פרסום מיידי של הודעות
  (התרומות מופיעות מרגע שליחתן, האדמיניסטרטורים יכולים
- למחקן לאחר מכן).',
+ למחקן לאחר מכן).', # MODIF
 
 	// D
 	'documents_interdits_forum' => 'בשלב זה נאסר בפורום',
@@ -68,7 +68,7 @@ return [
 	'info_desactiver_forum_public' => 'ביטול פעילות הפורומים
 הציבוריים. הפורומים הציבוריים יופעלו רק אחרי החלטה
 על המאמרם. לא יהיה אפשר להפעיל אותם על המדורים, על המבזקים וכו’.',
-	'info_envoi_forum' => 'שלח פורומים למחברי המאמרים',
+	'info_envoi_forum' => 'שלח פורומים למחברי המאמרים', # MODIF
 	'info_fonctionnement_forum' => ':פעולת הפורום',
 	'info_gauche_suivi_forum_2' => 'ה<i>forums follow-up</i> דף הוא לא אמצעי ניהול של אתרך (לא דיון או עריכה). הוא מציג את כל התרומות של הפורום הציבורי של המאמר הזה ומאפשר לך לנהל את התרומות האלה', # MODIF
 	'info_liens_syndiques_3' => 'פורומים',
