@@ -9,12 +9,12 @@ return [
 	'bouton_radio_articles_futurs' => 'လာမည့် ဆောင်ပါးအသစ်များ အ​တွက်သာ (သိုလောင် သိမ်းဆည်းထားသည်များနှင့်မဆိုင်)',
 	'bouton_radio_articles_tous' => 'လုံးဝခြွင်းချက်မရှိ ဆောင်းပါးများ အလုံးသို့',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'ဆောင်းပါးများ အလုံးသို့၊ သို့သော် ဖိုရမ်ပိတ်ထားသော ဆောင်းပါးများမပါ',
-	'bouton_radio_enregistrement_obligatoire' => 'မှတ်ပုံတင်ရန် လိုအပ်သည် (သုံးစွဲသူများ အနေဖြင့် အီးမေးလ်လိပ်စာ ပေးထားရပါမည်)',
+	'bouton_radio_enregistrement_obligatoire' => 'မှတ်ပုံတင်ရန် လိုအပ်သည် (သုံးစွဲသူများ အနေဖြင့် အီးမေးလ်လိပ်စာ ပေးထားရပါမည်)', # MODIF
 	'bouton_radio_moderation_priori' => 'ကြိုတင် ထိန်းသိမ်းထားခြင်း (ပါဝင်ရေးသားချက်များသည် ကြီးကြပ်သူမှ စစ်ဆေးအတည်ပြုပြီးမှသာ အများဆိုင်စာမျက်နှာတွင် ပေါ်လာမည်)', # MODIF
 	'bouton_radio_modere_abonnement' => 'မှတ်ပုံတင်ထားရန် လိုအပ်သည်',
 	'bouton_radio_modere_posteriori' => 'နောက်မှ ထိန်းသိမ်းခြင်း', # MODIF
 	'bouton_radio_modere_priori' => 'ကြိုတင် ထိန်းသိမ်းထားခြင်း', # MODIF
-	'bouton_radio_publication_immediate' => 'ချက်ချင်းထုတ်ပြန်ခြင်းအတွက် သတင်းအချက်အလက် (ပါဝင်ရေးသားချက်များ ပို့​ပြီးပြီးခြင်း ဖော်ပြမည်၊ အဲဒီနောက် ကြီးကြပ်သူများမှ ပယ်ဖျက်နိုင်သည်)',
+	'bouton_radio_publication_immediate' => 'ချက်ချင်းထုတ်ပြန်ခြင်းအတွက် သတင်းအချက်အလက် (ပါဝင်ရေးသားချက်များ ပို့​ပြီးပြီးခြင်း ဖော်ပြမည်၊ အဲဒီနောက် ကြီးကြပ်သူများမှ ပယ်ဖျက်နိုင်သည်)', # MODIF
 
 	// F
 	'form_pet_message_commentaire' => 'မှတ်ချက် တစ်စုံတစ်ရာ ပေးလိုပါသလား?',
@@ -54,7 +54,7 @@ return [
 	'info_appliquer_choix_moderation' => 'ဆုံးဖြတ်ခြင်းအတွက် သည်ရွေးချယ်မှုကိုပြုလုပ်ပါ',
 	'info_desactiver_forum_public' => 'အများဆိုင်ဖိုရမ်နှင့် ချိတ်ဆက်မှု မရနိုင်ပါ၊ ဆောင်းပါးများပေါ်မူတည်ပြီး အများဆိုင်ဖိုရမ်ကို ချိတ်ဆက်ခွင့်ပြုနိုင်သည်၊ 
 ၎င်းတို့သည် အခန်းကဏ္ဍအတွက် သတင်းစသည်များကို ခွင့်မပြုပါ',
-	'info_envoi_forum' => 'ဆောင်းပါးရေးသည့် စာရေးသူများသို့ ဖိုရမ်လိပ်စာကို ပို့လိုက်ပါ',
+	'info_envoi_forum' => 'ဆောင်းပါးရေးသည့် စာရေးသူများသို့ ဖိုရမ်လိပ်စာကို ပို့လိုက်ပါ', # MODIF
 	'info_fonctionnement_forum' => 'ဖိုရမ်​လုပ်ဆောင်မှု',
 	'info_gauche_suivi_forum_2' => '<i>ဖို​ရမ်နောက်ဆက်တွဲ</i> စာမျက်နှာသည် သင့်ဝက်ဘ်ဆိုက်၏ စီမံခန့်ခွဲသည့် ကိရိယာဖြစ်သည် (ဆွေးနွေးမှု (သို့) ပြန်လည်ပြုပြင်သည့် ဧရိယာမဟုတ်ပါ) ၄င်းသည်ဤဆောင်းပါး၏ အများသုံးဖိုရမ်ထည့်ဝင်မှုများကို ဖော်ပြပြီး ထိုထည့်ဝင်မှုများကို စီမံခွင့်ပြူသည် (အများသုံးဝက်ဘ်ဆိုက်နှင့် ကိုယ်ပိုင်နေရာနှစ်ခုစလုံး)', # MODIF
 	'info_liens_syndiques_3' => 'ဖိုရမ်များ',
@@ -65,8 +65,8 @@ return [
 	'info_mode_fonctionnement_defaut_forum_public' => 'အများသုံးဖိုရမ်များ၏ အခြားလုပ်ဆောင်မှုပုံစံ',
 	'info_option_email' => 'ဝင်ရောက်လည်ပတ်သူက ဆောင်းပါးနှင့်ပတ်သက်၍ မှတ်ချက်ထားရှိပါက ထို​ဆောင်းပါးရေးသူကို အီးမေးလ်ဖြင့် သတင်းပေးနိုင်သည်။ ဤရွေးချယ်မှုကို သုံးချင်ပါသလား', # MODIF
 	'info_pas_de_forum' => 'ဖိုရမ်မရှိပါ',
-	'item_activer_forum_administrateur' => 'ဝက်ဘ်ဆိုက်ကြီးကြပ်သူများဖိုရမ် ရနိုင်သည်',
-	'item_desactiver_forum_administrateur' => 'ဝက်ဘ်ဆိုက်ကြီကြပ်သူများဖိုရမ် မရနိုင်ပါ',
+	'item_activer_forum_administrateur' => 'ဝက်ဘ်ဆိုက်ကြီးကြပ်သူများဖိုရမ် ရနိုင်သည်', # MODIF
+	'item_desactiver_forum_administrateur' => 'ဝက်ဘ်ဆိုက်ကြီကြပ်သူများဖိုရမ် မရနိုင်ပါ', # MODIF
 
 	// L
 	'lien_reponse_article' => 'ဆောင်းပါးသို့ ပြန်တုန့်ပြန်ပါ',
@@ -86,7 +86,7 @@ return [
 	'statut_original' => 'မူရင်း',
 
 	// T
-	'titre_cadre_forum_administrateur' => 'ကြီးကြပ်သူ၏ ကိုယ်ပိုင်ဖိုရမ်',
+	'titre_cadre_forum_administrateur' => 'ကြီးကြပ်သူ၏ ကိုယ်ပိုင်ဖိုရမ်', # MODIF
 	'titre_cadre_forum_interne' => 'ဖိုရမ်အတွင်းပိုင်း',
 	'titre_forum' => 'ဖိုရမ်',
 	'titre_forum_suivi' => 'နောက်ဆက်တွဲဖိုရမ်',
