@@ -9,7 +9,7 @@ return [
 	'bouton_radio_articles_futurs' => 'wyłącznie do przyszłych artykułów (brak działania na bazie danych).',
 	'bouton_radio_articles_tous' => 'do wszystkich artykułów bez wyjątków.',
 	'bouton_radio_articles_tous_sauf_forum_desactive' => 'do wszystkich artykułów z wyjątkiem tych z nieczynnym forum.',
-	'bouton_radio_enregistrement_obligatoire' => 'Obowiązkowa rejestracja (użytkownicy muszą się zapisać przez podanie adresu e-mail aby mieć możliwość zamieszczania postów).',
+	'bouton_radio_enregistrement_obligatoire' => 'Obowiązkowa rejestracja (użytkownicy muszą się zapisać przez podanie adresu e-mail aby mieć możliwość zamieszczania postów).', # MODIF
 	'bouton_radio_moderation_priori' => 'Uprzednia moderacja (
  posty będą się ukazywać dopiero po ich zatwierdzeniu przez
  administratorów).', # MODIF
@@ -18,7 +18,7 @@ return [
 	'bouton_radio_modere_priori' => 'moderacja a priori', # MODIF
 	'bouton_radio_publication_immediate' => 'Natychmiastowa publikacja wiadomości
  (posty będą się ukazywać w momencie ich wysłania, administratorzy mogą
- je później usunąć).',
+ je później usunąć).', # MODIF
 
 	// F
 	'form_pet_message_commentaire' => 'Jakieś wiadomości lub komentarze?',
@@ -62,7 +62,7 @@ return [
 	'info_desactiver_forum_public' => 'Wyłącz możliwość korzystania z forum
  publicznego. Forum publiczne będzie można w pewnych przypadkach aktywować
  dołączając je do określonych artykułów ; wyłączenie będzie dotyczyło przede wszystkim działów i skrótów itd.',
-	'info_envoi_forum' => 'Wysyłka forum do autorów artykułów',
+	'info_envoi_forum' => 'Wysyłka forum do autorów artykułów', # MODIF
 	'info_fonctionnement_forum' => 'Funkcjonowanie forum :',
 	'info_gauche_suivi_forum_2' => 'Strona  <i>archiwum forum</i> jest narzędziem administracji stroną (a nie miejscem dyskusji czy redagowania). Wyświetla ona wszystkie komentarze forum z całego serwisu, zarówno te ze stron publicznych i strefy prywatnej i pozwala na zarządzanie tymi komentarzami.', # MODIF
 	'info_liens_syndiques_3' => 'forum',
@@ -75,8 +75,8 @@ return [
   związaną z artykułem, autorzy artykułu mogą zostać
   poinformowani o tym przez e-mail. Czy chcesz zastosować tę opcję?', # MODIF
 	'info_pas_de_forum' => 'brak forum',
-	'item_activer_forum_administrateur' => 'Aktywuj forum administratorów',
-	'item_desactiver_forum_administrateur' => 'Wyłącz forum administratorów',
+	'item_activer_forum_administrateur' => 'Aktywuj forum administratorów', # MODIF
+	'item_desactiver_forum_administrateur' => 'Wyłącz forum administratorów', # MODIF
 
 	// L
 	'lien_reponse_article' => 'Odpowiedz na ten artykuł',
@@ -96,7 +96,7 @@ return [
 	'statut_original' => 'oryginalny',
 
 	// T
-	'titre_cadre_forum_administrateur' => 'Prywatne forum administratorów',
+	'titre_cadre_forum_administrateur' => 'Prywatne forum administratorów', # MODIF
 	'titre_cadre_forum_interne' => 'Forum wewnętrzne',
 	'titre_forum' => 'Forum',
 	'titre_forum_suivi' => 'Archiwum forum',
