@@ -1121,7 +1121,7 @@ function spip_strlen($c) {
  *     La chaîne avec les caractères utf8 des hauts "planes" échappée
  *     en unicode : &#128169;
  */
-function utf8_noplanes($x): string {
+function utf8_noplanes(string $x): string {
 	$regexp_utf8_4bytes = '/(
       \xF0[\x90-\xBF][\x80-\xBF]{2}     # planes 1-3
    | [\xF1-\xF3][\x80-\xBF]{3}          # planes 4-15
