@@ -82,10 +82,10 @@ function cvtautosave_formulaire_charger($flux) {
 		/**
 		 * Envoyer le input hidden et le bout de js qui l'utilisera
 		 */
-		$flux['data']['_hidden'] .= "<input type='hidden' name='autosave' class='autosaveactive' value='$cle_autosave' />"
-			. '<script type="text/javascript">/*<![CDATA[*/if (window.jQuery) jQuery(function(){
+		$flux['data']['_hidden'] .= "<input type='hidden' name='autosave' class='autosaveactive' value='$cle_autosave'>"
+			. '<script>if (window.jQuery) jQuery(function(){
 		  $("input.autosaveactive").closest("form:not(.autosaveon)").autosave({url:"' . $GLOBALS['meta']['adresse_site'] . '/"}).addClass("autosaveon");
-			});/*]]>*/</script>';
+			});</script>';
 	}
 
 	return $flux;
