@@ -31,7 +31,7 @@ if (!defined('_ECRIRE_INC_VERSION')) {
  **/
 function inc_email_valide_dist($adresses) {
 	// eviter d'injecter n'importe quoi dans preg_match
-	if (!is_string($adresses)) {
+	if (!$adresses or !is_string($adresses)) {
 		return false;
 	}
 
