@@ -556,6 +556,20 @@ function _image_valeurs_trans($img, $effet, $forcer_format = false, $fonction_cr
 	return $ret;
 }
 
+/**
+ * Extensions d’images acceptées en tant que logos
+ * @param array{objet?: string, id_objet?: int, ...<string,mixed>} $args
+ * Arguments transmis au pipeline.
+ * Tableau contenant des informations sur le contexte d'appel.
+**/
+function _image_extensions_logos(array $args = []): array {
+	$global_formats_logos = $GLOBALS['formats_logos'];
+	if ($global_formats_logos != ['jpg', 'png', 'svg', 'gif', 'webp']) {
+		trigger_error('La modification de la globale `$formats_logos` est dépréciée, utiliser à la place le pipeline `image_extensions_logos`', E_USER_DEPRECATED);
+	}
+	$extensions = pipeline('image_extensions_logos', ['args' => $args, 'data' => $global_formats_logos]);
+	return $extensions;
+}
 
 /**
  * @param string $quoi
@@ -564,18 +578,14 @@ function _image_valeurs_trans($img, $effet, $forcer_format = false, $fonction_cr
 function _image_extensions_acceptees_en_entree() {
 	static $extensions = null;
 	if (empty($extensions)) {
-		$extensions = ['png', 'gif', 'jpg', 'jpeg'];
+		$extensions = ['png', 'gif', 'jpg', 'jpeg', 'svg'];
 		if (!empty($GLOBALS['meta']['gd_formats'])) {
 			// action=tester renseigne gd_formats et detecte le support de webp
-			$extensions = array_merge(explode(',', $GLOBALS['meta']['gd_formats']));
+			$extensions = array_merge($extensions, explode(',', (string) $GLOBALS['meta']['gd_formats']));
 			$extensions = array_map('trim', $extensions);
 			$extensions = array_filter($extensions);
-			if (in_array('jpg', $extensions)) {
-				$extensions[] = 'jpeg';
-			}
 			$extensions = array_unique($extensions);
 		}
-		$extensions[] = 'svg'; // on le supporte toujours avec des fonctions specifiques
 	}
 
 	return $extensions;
