@@ -293,7 +293,7 @@ function couleur_eclaircir($couleur, $coeff = 0.5) {
  * dans la fonction image_filtrer
  *
  * @param string $img
- *    Un tag html `<img src=... />`.
+ *    Un tag html `<img src=...>`.
  * @param int $width_min
  *    Largeur minimale de l'image à traiter (0 par défaut)
  * @param int $height_min
@@ -303,7 +303,7 @@ function couleur_eclaircir($couleur, $coeff = 0.5) {
  * @param int $height_max
  *    Hauteur minimale de l'image à traiter (10000 par défaut)
  * @return
- *    Le tag html `<img src=... />` avec une class `filtre_inactif` ou pas
+ *    Le tag html `<img src=...>` avec une class `filtre_inactif` ou pas
  */
 function image_select($img, $width_min = 0, $height_min = 0, $width_max = 10000, $height_max = 1000) {
 	if (!$img) {
@@ -510,10 +510,11 @@ function image_recadre_avec_fallback(
 	$position = 'focus',
 	$background_color = 'white'
 ) {
+	$im = image_passe_partout($im, $width, $height);
 	if (function_exists('image_recadre') && ($GLOBALS['meta']['image_process'] ?? '') === 'gd2') {
-		return image_reduire(image_recadre($im, $width . ':' . $height, '-', $position, $background_color), $width, $height);
-	} else { return image_passe_partout($im, $width, $height);
+		$im = image_recadre($im, $width . ':' . $height, '-', $position, $background_color);
 	}
+	return $im;
 }
 
 /**
