@@ -144,9 +144,10 @@ function redirige_formulaire($url, $equiv = '', $format = 'message') {
 		$url = strtr($url, "\n\r", '  ');
 		# en theorie on devrait faire ca tout le temps, mais quand la chaine
 		# commence par ? c'est imperatif, sinon l'url finale n'est pas la bonne
-		if ($url[0] == '?') {
-			$url = url_de_base() . $url;
+		if (in_array($url[0], ['?', '/']) && !str_starts_with($url, '//')) {
+			$url = url_de_base() . ltrim($url, '/');
 		}
+
 		$url = str_replace('&amp;', '&', $url);
 		spip_log("redirige formulaire ajax: $url");
 		include_spip('inc/filtres');
