@@ -113,7 +113,7 @@ function f_boite_infos($flux) {
 		$type = 'objet';
 	}
 	$args['espace_prive'] = 1;
-	$flux['data'] .= recuperer_fond("prive/objets/infos/$type", $args);
+	$flux['data'] .= recuperer_fond("prive/objets/infos/$type", $args, ['ajax' => true]);
 
 	return $flux;
 }
