@@ -153,8 +153,9 @@ function install_etape_2_form($hidden, $checked, $res, $etape) {
 	return generer_form_ecrire('install', (
 		"\n<input type='hidden' name='etape' value='$etape'>"
 		. $hidden
-		. (defined('_INSTALL_NAME_DB')
-			? '<h3>' . _T('install_nom_base_hebergeur') . ' <tt>' . _INSTALL_NAME_DB . '</tt>' . '</h3>'
+		. (
+			defined('_INSTALL_NAME_DB')
+			? '<h3>' . _T('install_nom_base_hebergeur') . ' <code>' . _INSTALL_NAME_DB . '</code>' . '</h3>'
 			: "\n<fieldset><legend>" . _T('texte_choix_base_1') . "</legend>\n"
 			. $res
 			. "\n<input name=\"choix_db\" value=\"new_spip\" type='radio' id='nou'"
@@ -163,9 +164,9 @@ function install_etape_2_form($hidden, $checked, $res, $etape) {
 			. "\n<input type='text' name='table_new' class='text' value=\"spip\" size='20'></p></fieldset>\n"
 		)
 
-		. ((defined('_INSTALL_TABLE_PREFIX')
-			or $GLOBALS['table_prefix'] != 'spip')
-			? '<h3>' . _T('install_table_prefix_hebergeur') . '  <tt>' . $GLOBALS['table_prefix'] . '</tt>' . '</h3>'
+		. (
+			(defined('_INSTALL_TABLE_PREFIX') || $GLOBALS['table_prefix'] != 'spip')
+			? '<h3>' . _T('install_table_prefix_hebergeur') . '  <code>' . $GLOBALS['table_prefix'] . '</code>' . '</h3>'
 			: '<fieldset><legend>' . _T('texte_choix_table_prefix') . "</legend>\n"
 			. "<p><label for='table_prefix'>" . _T('info_table_prefix') . '</label></p><p>'
 			. "\n<input type='text' id='tprefix' name='tprefix' class='text' value='"
