@@ -65,7 +65,7 @@ return [
 	'bouton_relancer_inscription' => 'Relancer l’inscription',
 	'bouton_relancer_inscriptions' => 'Relancer les inscriptions',
 	'bouton_relancer_installation' => 'Relancer l’installation',
-	'bouton_reset_password' => 'Générer un nouveau mot de passe et l’envoyer par email',
+	'bouton_reset_password' => 'Envoyer un lien pour choisir son mot de passe',
 	'bouton_suivant' => 'Suivant',
 	'bouton_tenter_recuperation' => 'Tenter une réparation',
 	'bouton_test_proxy' => 'Essayer le proxy',
@@ -209,6 +209,14 @@ return [
 	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.',
 	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.',
 	'info_1_article' => '1 article',
+	'info_1_article_a_paraitre' => '1 article à paraître',
+	'info_1_article_meme_rubrique' => '1 article dans la même rubrique',
+	'info_1_article_propose' => '1 article proposé',
+	'info_1_article_publie' => '1 article publié',
+	'info_1_article_recent' => 'L’article le plus récent',
+	'info_1_article_redac' => '1 article en cours de rédaction',
+	'info_1_article_refuse' => '1 article refusé',
+	'info_1_article_rubrique' => '1 article publié dans la rubrique',
 	'info_1_auteur' => '1 auteur',
 	'info_1_message' => '1 message',
 	'info_1_mot_cle' => '1 mot-clé',
@@ -383,6 +391,13 @@ exige d’avoir un accès FTP au site Web.</p>',
 	'info_multi_objets' => '@objets@ : activer le menu de langue',
 	'info_multi_secteurs' => '... seulement pour les rubriques situées à la racine ?',
 	'info_nb_articles' => '@nb@ articles',
+	'info_nb_articles_a_paraitre' => '@nb@ articles à paraître',
+	'info_nb_articles_meme_rubrique' => '@nb@ articles dans la même rubrique',
+	'info_nb_articles_proposes' => '@nb@ articles proposés',
+	'info_nb_articles_publies' => '@nb@ articles publiés',
+	'info_nb_articles_recents' => 'Les @nb@ articles les plus récents',
+	'info_nb_articles_redacs' => '@nb@ articles en cours de rédaction',
+	'info_nb_articles_refuses' => '@nb@ articles refusés',
 	'info_nb_auteurs' => '@nb@ auteurs',
 	'info_nb_messages' => '@nb@ messages',
 	'info_nb_mots_cles' => '@nb@ mots-clés',
