@@ -3,14 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=uk
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
-	'activer_plugin' => 'Активувати плагін',
+	'activer_plugin' => 'Увімкнути плагін',
 	'affichage' => 'Показати',
 	'aide_non_disponible' => 'Цей розділ он-лайн допомоги ще не перекладено українською.',
 	'annuler_recherche' => 'Відмінити пошук',
@@ -19,19 +15,22 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'avis_acces_interdit_prive' => 'У вас немає прав для перегляду сторінки <b>@exec@</b>.',
 	'avis_article_modifie' => 'Увага: @nom_auteur_modif@ вносив зміни в цю статтю @date_diff@ хвилин тому',
 	'avis_aucun_resultat' => 'Нічого не знайдено',
-	'avis_base_inaccessible' => 'Неможливо підключитися до бази @base@.',
+	'avis_base_inaccessible' => 'Неможливо підключитися до бази даних @base@.',
 	'avis_chemin_invalide_1' => 'Шлях, що ви вибрали',
 	'avis_chemin_invalide_2' => 'схоже, що не вірно. Будь ласка, поверніться на попередню сторінку і перевірте надану інформацію.',
-	'avis_connexion_echec_1' => 'Не вдалося підключится до SQL серверу.',
+	'avis_connexion_echec_1' => 'Не вдалося підключится до бази даних.',
 	'avis_connexion_echec_2' => 'Будь ласка, поверніться на попередню сторінку і перевірте внесену інформацію.',
-	'avis_connexion_echec_3' => '<b>N.B.</b> На багатьох серверах ви повинні зробити запит для включення вашого доступу до бази даних SQL перед тим, як використовувати її. Якщо ви не можете встановити з’єднання, упевніться, що цей запит дійсно було зроблено.',
+	'avis_connexion_echec_3' => '<b>N.B.</b> На багатьох серверах ви повинні зробити запит для включення вашого доступу до бази даних перед тим, як використовувати її. Якщо ви не можете встановити з’єднання, упевніться, що цей запит дійсно було зроблено.',
 	'avis_connexion_erreur_creer_base' => 'База даних не може бути створена.',
+	'avis_connexion_erreur_fichier_cle_manquant_1' => 'Установку повинен виконати вебмастер, який має резервні копії ключів та їх паролів', # MODIF
+	'avis_connexion_erreur_fichier_cle_manquant_2' => 'Установку повинен виконати вебмастер, який має резервні копії ключів ', # MODIF
 	'avis_connexion_erreur_nom_base' => 'Назва бази може складатися тільки з латинських букв, цифр і знаків нижнього підкреслювання.',
 	'avis_connexion_ldap_echec_1' => 'Не вдалося подключитися до LDAP.',
 	'avis_connexion_ldap_echec_2' => 'Поверніться на попередню сторінку і перевірте внесену вами інформацію.',
-	'avis_connexion_ldap_echec_3' => 'Крім того, не використовуйте підтримку LDAP для імпорту користувачів.',
+	'avis_connexion_ldap_echec_3' => 'Крім того, не використовуйте підтримку LDAP для імпорту користувачів.', # MODIF
 	'avis_deplacement_rubrique' => 'Увага! В цій рубриці знаходиться @contient_breves@ новин@scb@: якщо ви переміщуєте її, будь ласка, поставьте відмітку для підтвердження операції.',
-	'avis_erreur_connexion_mysql' => 'Помилка з’єднання з SQL ',
+	'avis_erreur_connexion_mysql' => 'Помилка з’єднання з базою даних',
+	'avis_erreur_creation_compte' => 'Помилка при ініціалізації облікового запису',
 	'avis_espace_interdit' => '<b>Заборонений простір</b> <div>SPIP вже встановлено.</div> ',
 	'avis_lecture_noms_bases_1' => 'Програма установки не змогла прочитати імена встановлених баз даних .',
 	'avis_lecture_noms_bases_2' => 'Жодна з баз даних не є доступною або функцію, що дозволяє вносити до списку бази даних, було вимкнено з метою безпеки (забагато послуг хостингу).',
@@ -56,10 +55,10 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bouton_mettre_a_jour_base' => 'Оновити базу даних',
 	'bouton_modifier' => 'Змінити',
 	'bouton_radio_afficher' => 'Показати',
-	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Показувати у переліку авторів, що знаходяться на сайті',
+	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Показувати у переліку авторів, що знаходяться на сайті', # MODIF
 	'bouton_radio_envoi_annonces_adresse' => 'Відправити оголошення на адресу:',
 	'bouton_radio_envoi_liste_nouveautes' => 'Відправити список останніх новин',
-	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Не показувати у переліку авторів, що знаходяться на сайті',
+	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Не показувати у переліку авторів, що знаходяться на сайті', # MODIF
 	'bouton_radio_non_envoi_annonces_editoriales' => 'Не відправляти ніяких редакційних оголошень',
 	'bouton_redirection' => 'ПЕРЕНАПРАВЛЕННЯ',
 	'bouton_reinitialiser_aux_valeurs_par_defaut' => 'Відновити початкові значення',
@@ -73,7 +72,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bouton_vider_cache' => 'Очистити кеш',
 
 	// C
-	'cache_modifiable_webmestre' => 'Цей параметр може бути змінений тільки вебмастером.',
+	'cache_modifiable_webmestre' => 'Цей параметр може бути змінений тільки вебмастером.', # MODIF
 	'calendrier_synchro' => 'Якщо ви використовуєте календар, сумісний з <b>iCal</b>, ви можете узгодити його з даними сайту.',
 	'config_activer_champs' => 'Увімкнути наступні поля',
 	'config_choix_base_sup' => 'Виберіть базу на цьому сервері',
@@ -118,7 +117,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'entree_contenu_rubrique' => '(Короткий зміст рубрики.)',
 	'entree_identifiants_connexion' => 'Логін і пароль',
 	'entree_identifiants_connexion_2' => 'Інформація про підключення',
-	'entree_informations_connexion_ldap' => 'Будь ласка, вкажіть параметри підключення до LDAP. Ви можете отримати цю інформацію у вашого системного адміністратора.',
+	'entree_informations_connexion_ldap' => 'Будь ласка, вкажіть параметри підключення до LDAP. Ви можете отримати цю інформацію у вашого системного адміністратора.', # MODIF
 	'entree_infos_perso' => 'Хто ви?',
 	'entree_infos_perso_2' => 'Хто автор?',
 	'entree_interieur_rubrique' => 'В розділі:',
@@ -216,17 +215,18 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_activer_menu_developpement' => 'Показати меню розвитку',
 	'info_admin_etre_webmestre' => 'Надати мені права вебмастера',
 	'info_admin_je_suis_webmestre' => 'Я <b>вебмастер</b>',
-	'info_admin_statuer_webmestre' => 'Надати цьому адміністратору права веб-майстра',
-	'info_admin_webmestre' => 'Адміністратор є <b>вебмастером</b>',
-	'info_administrateur' => 'Адміністратор',
-	'info_administrateur_1' => 'Адміністратор',
+	'info_admin_statuer_webmestre' => 'Надати цьому адміністратору права веб-майстра', # MODIF
+	'info_admin_webmestre' => 'Адміністратор є <b>вебмастером</b>', # MODIF
+	'info_administrateur' => 'Адміністратор', # MODIF
+	'info_administrateur_1' => 'Адміністратор', # MODIF
 	'info_administrateur_2' => 'на цьому сайті (<i>використовувати з пересторогою</i>)',
-	'info_administrateur_site_01' => 'Якщо ви адміністратор сайта, будь ласка',
+	'info_administrateur_site_01' => 'Якщо ви адміністратор сайта, будь ласка', # MODIF
 	'info_administrateur_site_02' => 'натисніть тут',
-	'info_administrateurs' => 'Адміністратори',
+	'info_administrateurs' => 'Адміністратори', # MODIF
 	'info_administrer_rubrique' => 'Ви можете управляти цією рубрикою',
 	'info_adresse' => 'за адресою:',
 	'info_adresse_desinscription' => 'Адреса щоб відписатися:',
+	'info_adresse_inscription' => 'Адреса реєстрації :',
 	'info_adresse_url' => 'Адреса (URL) загального сайту',
 	'info_afficher_par_nb' => 'Показати',
 	'info_aide_en_ligne' => 'SPIP Oнлайн Допомога',
@@ -263,7 +263,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_chapeau' => 'Вступ',
 	'info_chapeau_2' => 'Вступ:',
 	'info_chemin_acces_1' => 'Опції: <b>Шлях доступу до каталогу</b>',
-	'info_chemin_acces_2' => 'Тепер ви повинні налаштувати шлях доступу до інформації в  довіднику. Ця інформація необхідна для перегляду профілів користувачів, записаних в  довіднику.',
+	'info_chemin_acces_2' => 'Тепер ви повинні налаштувати шлях доступу до інформації в  довіднику. Ця інформація необхідна для перегляду профілів користувачів, записаних в  довіднику.', # MODIF
 	'info_chemin_acces_annuaire' => 'Опції: <b>Шлях доступу к каталогу</b>',
 	'info_choix_base' => 'Третій етап:',
 	'info_classement_1' => ' з @liste@',
@@ -298,7 +298,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_ecrire_article' => 'Перед тим, як писати статті, необхідно створити хоча б одну рубрику.',
 	'info_email_envoi' => ' Адреса електронної пошти (необов’язково)',
 	'info_email_envoi_txt' => 'Введіть e-mail адресу відправника, що використовується для відправлення електронних листів (зазвичай адреса користувача використовується як адреса відправника):',
-	'info_email_webmestre' => 'E-mail веб-мастера',
+	'info_email_webmestre' => 'E-mail веб-мастера', # MODIF
 	'info_envoi_email_automatique' => 'Автоматична відправка повідомлення електронної пошти ',
 	'info_envoyer_maintenant' => 'Відправити зараз',
 	'info_etape_suivante' => 'Перейти до наступного етапу',
@@ -306,14 +306,13 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_etape_suivante_2' => 'Ви можете перейти до наступного етапу.',
 	'info_exceptions_proxy' => 'Винятки для проксі',
 	'info_exportation_base' => 'експортувати базу даних в @archive@',
-	'info_facilite_suivi_activite' => 'Для полегшення моніторингу діяльності   редакційних SPIP сайт може відправити його поштою, наприклад, на  список розсилки редакторів, бізнес-додатки публікації та перевірки статей.', # MODIF
+	'info_facilite_suivi_activite' => 'SPIP може повідомляти по електронній пошті,  щодо нових запитів на публікацію та схвалення статей. Вкажіть одну або кілька адрес, розділених комами.', # MODIF
 	'info_fichiers_authent' => 'Файл аутентифікації «.htpasswd»',
-	'info_forums_abo_invites' => 'Ваш сайт має форуми за підпискою; відвідувачі можуть зареєструватися на них на основному сайті.',
+	'info_forums_abo_invites' => 'Ваш сайт має форуми за підпискою; відвідувачі можуть зареєструватися на них на основному сайті.', # MODIF
 	'info_gauche_admin_tech' => '<b>Сторінка тільки для вебмастера сайта.</b> <p>Ви можете виконувати завдання щодо експлуатації сайту. Частина з них може потребувати FTP-доступу до сайту.</p>',
-	'info_gauche_admin_vider' => '<b>Тільки вебмастери мають доступ до цієї сторінки.</b> <p>Тут є можливість виконувати різні завдання по обслуговуванню сайта. Для виконання окремих завдань необхідний доступ до сайту по FTP.</p>',
-	'info_gauche_auteurs' => 'Перелік всіх авторів сайту. Статус автора позначений кольором (адміністратор = зелений; автор = жовтий).',
+	'info_gauche_auteurs' => 'Перелік всіх авторів сайту. Статус автора позначений кольором (адміністратор = зелений; автор = жовтий).', # MODIF
 	'info_gauche_auteurs_exterieurs' => 'Користувачі, що зареєструвалися, позначені синім кольором, а видалені користувачі - іконкою кошика.',
-	'info_gauche_messagerie' => 'Передача повідомлень дозволяє обмінюватися повідомленнями між редакторами, зберигати нотатки (для вашого особистого використання) або показувати оголошення на основній сторінці адміністративної частини (якщо ви - адміністратор).',
+	'info_gauche_messagerie' => 'Передача повідомлень дозволяє обмінюватися повідомленнями між редакторами, зберигати нотатки (для вашого особистого використання) або показувати оголошення на основній сторінці адміністративної частини (якщо ви - адміністратор).', # MODIF
 	'info_gauche_statistiques_referers' => 'Ця сторінка показує список <i>посилань</i>, тобто ті сайти, які мають посилання на ваш сайт, тільки для вчора і сьогодні: фактично цей список поновлюється кожні 24 години.',
 	'info_gauche_visiteurs_enregistres' => 'Ви знайдете тут зареєстрованних відвідувачів основноі частини сайту (форуми за підпискою).',
 	'info_generation_miniatures_images' => 'Створення зменшених зображень',
@@ -326,7 +325,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_images_auto' => 'Кеш файлів зображень',
 	'info_informations_personnelles' => 'Налаштування профиля',
 	'info_inscription' => 'Реєстрація',
-	'info_inscription_automatique' => 'Автоматична реєстрація нових авторів',
+	'info_inscription_automatique' => 'Автоматична реєстрація нових авторів', # MODIF
 	'info_jeu_caractere' => 'Кодування сайту',
 	'info_jours' => 'дні',
 	'info_laisser_champs_vides' => 'залиште ці поля порожніми)',
@@ -334,7 +333,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_ldap_ok' => 'Встанослення справжності LDAP.',
 	'info_lien_hypertexte' => 'Гиперпосилання:',
 	'info_liste_nouveautes_envoyee' => 'Інформацію про останні оновлення відправлено',
-	'info_liste_redacteurs_connectes' => 'Автори онлайн',
+	'info_liste_redacteurs_connectes' => 'Автори онлайн', # MODIF
 	'info_login_existant' => 'Цей логін вже використовується.',
 	'info_login_trop_court' => 'Занадто короткий логін.',
 	'info_login_trop_court_car_pluriel' => 'Логін повинен складатися мінімум з @nb@ символів.',
@@ -353,7 +352,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_mon_site_spip' => 'Мій сайт ',
 	'info_moyenne' => 'в средньому:',
 	'info_multi_cet_article' => 'Мова статті:',
-	'info_multi_langues_choisies' => 'Виберіть мови для редагування матеріалів на сайті. Мови, які вже використовує ваш сайт (наверху списку) не можуть бути вимкнені.',
+	'info_multi_langues_choisies' => 'Виберіть мови для редагування матеріалів на сайті. Мови, які вже використовує ваш сайт (наверху списку) не можуть бути вимкнені.', # MODIF
 	'info_multi_objets' => '@objets@ : увімкнути мовне меню',
 	'info_multi_secteurs' => '... тільки для розділів в корені сайту?',
 	'info_nb_articles' => '@nb@ статтей',
@@ -380,8 +379,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_nouvelle_traduction' => 'Новий переклад:',
 	'info_numero_article' => 'НОМЕР СТАТТІ:',
 	'info_obligatoire_02' => '(обов’язково)',
-	'info_option_accepter_visiteurs' => 'Увімкнути реєстрацію відвідувачів на сайті',
-	'info_option_ne_pas_accepter_visiteurs' => 'Відключити реєстрацію відвідувачів на сайті',
+	'info_option_accepter_visiteurs' => 'Увімкнути реєстрацію відвідувачів на сайті', # MODIF
+	'info_option_ne_pas_accepter_visiteurs' => 'Відключити реєстрацію відвідувачів на сайті', # MODIF
 	'info_options_avancees' => 'ДОДАТКОВІ НАЛАШТУВАННЯ',
 	'info_ou' => 'або...',
 	'info_page_interdite' => 'Заборонена сторінка',
@@ -399,15 +398,15 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_post_scriptum' => 'Постскриптум',
 	'info_post_scriptum_2' => 'Постскриптум: ',
 	'info_pour' => 'для',
-	'info_preview_texte' => 'Налаштування попереднього перегляду. Ви можете подивитися, як виглядають на сайті матеріали зі статусом «представлено». Увімкнути цю можливість для усіх авторів, тільки для адміністраторов або відключити взагалі?',
+	'info_preview_texte' => 'Налаштування попереднього перегляду. Ви можете подивитися, як виглядають на сайті матеріали зі статусом «представлено». Увімкнути цю можливість для усіх авторів, тільки для адміністраторов або відключити взагалі?', # MODIF
 	'info_procedez_par_etape' => 'Будь ласка, виконуйте покроково',
 	'info_procedure_maj_version' => 'необхідно запустити процедуру оновлення поточної бази даних для новоі версії SPIP.',
 	'info_proxy_ok' => 'Проксі сервер працює.',
 	'info_ps' => 'P.S.',
 	'info_publier' => 'опублікувати',
 	'info_publies' => 'Ваші статті, опубліковані на сайті:',
-	'info_question_accepter_visiteurs' => 'Якщо шаблони вашого сайту дозволяють відвідувачам реєструватися, не входячи в адміністративну частину, будь ласка, включіть наступну опцію:',
-	'info_question_inscription_nouveaux_redacteurs' => 'Ви хочете дозволити реєстрацію нових користувачів на сайті? Якщо так, то відвідувачі зможуть реєструватися самостійно, використовуючи стандартну форму. Також у них буде доступ в адміністративну частину сайту і можливість створювати нові матеріали.  <div class="notice">Пароль для доступу буде відправлено користувачу  email’ом автоматично. Якщо ваш хостінг не підтримує відправку листів, то ця опція буде марна.</div>',
+	'info_question_accepter_visiteurs' => 'Якщо шаблони вашого сайту дозволяють відвідувачам реєструватися, не входячи в адміністративну частину, будь ласка, включіть наступну опцію:', # MODIF
+	'info_question_inscription_nouveaux_redacteurs' => 'Ви хочете дозволити реєстрацію нових користувачів на сайті? Якщо так, то відвідувачі зможуть реєструватися самостійно, використовуючи стандартну форму. Також у них буде доступ в адміністративну частину сайту і можливість створювати нові матеріали.  <div class="notice">Пароль для доступу буде відправлено користувачу  email’ом автоматично. Якщо ваш хостінг не підтримує відправку листів, то ця опція буде марна.</div>', # MODIF
 	'info_qui_edite' => '@nom_auteur_modif@ працював над цим матеріалом @date_diff@ хвилин назад',
 	'info_racine_site' => 'Корінь сайту',
 	'info_recharger_page' => 'Будь ласка перезавантажте цю сторінку через декілька хвилин.',
@@ -424,7 +423,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_refuses' => 'Ваші відхилені статті',
 	'info_reglage_ldap' => 'Опції <b>налаштування імпорту LDAP</b>',
 	'info_renvoi_article' => 'Відвідувач будет перенаправлений за наступним посиланням',
-	'info_reserve_admin' => 'Тільки адміністратори можуть змінити цю адресу.',
+	'info_reserve_admin' => 'Тільки адміністратори можуть змінити цю адресу.', # MODIF
 	'info_restreindre_rubrique' => 'Надати права управління розділами:',
 	'info_resultat_recherche' => 'Результати пошуку:',
 	'info_rubriques' => 'Розділи',
@@ -443,14 +442,14 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_sites_proxy' => 'Використовувати проксі',
 	'info_sites_trouves' => 'знайдені сайти',
 	'info_sous_titre' => 'Підзаголовок:',
-	'info_statut_administrateur' => 'Адміністратор',
+	'info_statut_administrateur' => 'Адміністратор', # MODIF
 	'info_statut_auteur' => 'Статус автора:',
 	'info_statut_auteur_2' => 'Я',
 	'info_statut_auteur_a_confirmer' => 'Реєстрація буде підтверджена',
 	'info_statut_auteur_autre' => 'Інший статус:',
 	'info_statut_redacteur' => 'Автор',
-	'info_statut_utilisateurs_1' => 'Усталений (default) статус для імпортованих користувачів',
-	'info_statut_utilisateurs_2' => 'Виберіть статус, що буде використовуватися для людей з каталогу LDAP, коли вони підключаться вперше. Пізніше ви зможете змінити це значення для кожного автора індивідуально.',
+	'info_statut_utilisateurs_1' => 'Усталений (default) статус для імпортованих користувачів', # MODIF
+	'info_statut_utilisateurs_2' => 'Виберіть статус, що буде використовуватися для людей з каталогу LDAP, коли вони підключаться вперше. Пізніше ви зможете змінити це значення для кожного автора індивідуально.', # MODIF
 	'info_suivi_activite' => 'Відстежування роботи редакторів',
 	'info_surtitre' => 'Топ-заголовок:',
 	'info_syndication_integrale_1' => 'Ваш сайт пропонує об’єднані файли (див. «<a href="@url@">@titre@</a>»).',
@@ -494,7 +493,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_visiteur_2' => 'з основної частини сайту',
 	'info_visiteurs' => 'Відвідувачі',
 	'info_visiteurs_02' => 'Відвідувачі основної частини сайту',
-	'info_webmestre_forces' => 'Список вебмастерів міститься в <tt>@file_options@</tt>.',
+	'info_webmestre_forces' => 'Список вебмастерів міститься в <tt>@file_options@</tt>.', # MODIF
 	'install_adresse_base_hebergeur' => 'Адресу серверу бази даних ви можете дізнатися у свого хостера',
 	'install_connect_ok' => 'Була оголошена нова база на сервері @connect@.',
 	'install_echec_annonce' => 'Ця інсталяция, напевне, не буде працювати або приведе до нестійкої роботи сайту...',
@@ -504,7 +503,9 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'install_nom_base_hebergeur' => 'Ім’я бази даних визначається постачальником послуг:',
 	'install_pas_table' => 'В базе даних ще нема таблиць',
 	'install_pass_base_hebergeur' => 'Ви можете встановити пароль через контрольну панель хостінгу або запитати його в службі підтримки вашого хостінгу.',
+	'install_php_extension' => 'Не вистачає наступних розширень або плагінів: @extensions@',
 	'install_php_version' => 'Версія PHP @version@ надто стара (мінімум = @minimum@)',
+	'install_php_version_max' => 'Версія PHP @version@ занадто нова (найновіша, що підтримується = @maximum@)',
 	'install_select_langue' => 'Виберіть мову, потім натисніть кнопку «далі», щоб начати процедуру встановлення.',
 	'install_select_type_db' => 'Вкажіть тип бази даних:',
 	'install_select_type_mysql' => 'MySQL',
@@ -522,10 +523,10 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'intitule_licence' => 'Дозвіл',
 	'item_accepter_inscriptions' => 'Дозволити реєстрацію',
 	'item_activer_messages_avertissement' => 'Попереджати про сумісну роботу',
-	'item_administrateur_2' => 'адміністратор',
+	'item_administrateur_2' => 'адміністратор', # MODIF
 	'item_afficher_calendrier' => 'показувати в календарі',
 	'item_autoriser_syndication_integrale' => 'Включати цілі статті в об’єднані файли ',
-	'item_choix_administrateurs' => 'адміністратори',
+	'item_choix_administrateurs' => 'адміністратори', # MODIF
 	'item_choix_generation_miniature' => 'Створювати зменшені копії автоматично.',
 	'item_choix_non_generation_miniature' => 'Не створювати зменшені копії.',
 	'item_choix_redacteurs' => 'редактори',
@@ -559,6 +560,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'label_bando_outils_afficher' => 'Показати інструменти',
 	'label_bando_outils_masquer' => 'Сховати інструменти',
 	'label_choix_langue' => 'Мова інтерфейсу',
+	'label_langue' => 'Мова',
 	'label_nom_fichier_connect' => 'Відображати ім’я серверу',
 	'label_slogan_site' => 'Слоган сайту',
 	'label_taille_ecran' => 'Ширина робочої області',
@@ -694,14 +696,20 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'protocole_ldap' => 'Версія протоколу:',
 
 	// Q
+	'queue_args_fonction_label' => 'Аргументи передані функції @fonction@',
+	'queue_args_voir' => 'Показати аргументи',
 	'queue_executer_maintenant' => 'Запустити',
+	'queue_fonction_label' => 'Функція',
 	'queue_info_purger' => 'Ви можете видалити усі поточні завдання і очистити всю чергу завдань',
+	'queue_liens_label' => 'Посилання',
 	'queue_nb_jobs_in_queue' => 'В черзі @nb@ завдань',
 	'queue_next_job_in_nb_sec' => 'Наступне завдання через @nb@ s',
+	'queue_next_job_scheduled' => 'Наступна задача (task)',
 	'queue_no_job_in_queue' => 'Список завдань пустий',
 	'queue_one_job_in_queue' => '1 завдання в черзі',
 	'queue_priorite_tache' => 'пріорітет',
 	'queue_purger_queue' => 'Очистити список завдань',
+	'queue_statut_en_cours' => 'Вмконується',
 	'queue_titre' => 'Список завдань',
 
 	// R
@@ -723,15 +731,15 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'taille_repertoire_cache' => 'Поточний розмір кеша',
 	'text_article_propose_publication' => 'Статтю представлено до публікації.',
 	'texte_acces_ldap_anonyme_1' => 'Деякі сервери LDAP не дозволяють анонімного доступу. В цьому випадку ви повинні вказати вихідний ідентифікатор доступу, щоб згодом мати можливість шукати інформацію в каталозі. Але в більшості випадків наступні поля можна залишити порожніми.',
-	'texte_admin_effacer_01' => 'Ця команда видаляє <i>увесь</i> вміст бази даних, включаючи <i>усі</i> параметри доступу для редакторів і адміністраторів. Після її виконання ви повинні перевстановити SPIP, щоб відновити нову базу даних і доступ першого адміністратора.',
+	'texte_admin_effacer_01' => 'Ця команда видаляє <i>увесь</i> вміст бази даних, включаючи <i>усі</i> параметри доступу для редакторів і адміністраторів. Після її виконання ви повинні перевстановити SPIP, щоб відновити нову базу даних і доступ першого адміністратора.', # MODIF
 	'texte_adresse_annuaire_1' => '(Якщо ваш каталог установлено на тому ж самому комп’ютері, що і ваш вебсайт, це, напевно, - «localhost».)',
 	'texte_ajout_auteur' => 'Наступний автор був доданий до статті:',
-	'texte_annuaire_ldap_1' => 'Якщо ви маєте доступ до каталогу(LDAP), то можете використовувати його для автоматичного імпорту користувачів SPIP.',
+	'texte_annuaire_ldap_1' => 'Якщо ви маєте доступ до каталогу(LDAP), то можете використовувати його для автоматичного імпорту користувачів SPIP.', # MODIF
 	'texte_article_statut' => 'Статус статті:',
 	'texte_article_virtuel' => 'Віртуальна стаття',
 	'texte_article_virtuel_reference' => '<b>Віртуальна стаття:</b> стаття, на яку є посилання на вашому SPIP сайті, але яка насправді знаходиться на іншому URL. Щоб видалити перенаправлення, видаліть адресу, яку наведено вище.',
 	'texte_aucun_resultat_auteur' => 'Нема результатів для «@cherche_auteur@».',
-	'texte_auteur_messagerie' => 'Цей сайт може постійнно контролювати список редакторів, які знаходяться он-лайн, що дозволяє вам обмінюватися повідомленнями в реальному часі. Ви можете вирішити не з’являтися в цьому списку (тоді вас «не побачать» інші користувачі).',
+	'texte_auteur_messagerie' => 'Цей сайт може постійнно контролювати список редакторів, які знаходяться он-лайн, що дозволяє вам обмінюватися повідомленнями в реальному часі. Ви можете вирішити не з’являтися в цьому списку (тоді вас «не побачать» інші користувачі).', # MODIF
 	'texte_auteurs' => 'АВТОРИ',
 	'texte_choix_base_1' => 'Вибрати вашу базу даних:',
 	'texte_choix_base_2' => 'SQL сервер містить декілька баз даних.',
@@ -757,7 +765,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'texte_effacer_statistiques' => 'Видалити статистику',
 	'texte_en_cours_validation' => 'Матеріали, що потребують перевірки. ',
 	'texte_enrichir_mise_a_jour' => 'Ви можете покращити свій текст, користуючись «типографськими скороченнями»',
-	'texte_fichier_authent' => '<b>Чи повинен SPIP створювати <tt>.htpasswd</tt> і <tt>.htpasswd-admin</tt> файли у папці @dossier@?</b> <p>Ці файли використовуються для обмеження доступу авторів і адміністраторов до інших частин сайту (наприклад, до папки з серверною статистикою).</p> <p>Якщо у вас нема необхідності в таких діях, то залиште це значення як усталено (default).</p>',
+	'texte_fichier_authent' => '<b>Чи повинен SPIP створювати <tt>.htpasswd</tt> і <tt>.htpasswd-admin</tt> файли у папці @dossier@?</b> <p>Ці файли використовуються для обмеження доступу авторів і адміністраторов до інших частин сайту (наприклад, до папки з серверною статистикою).</p> <p>Якщо у вас нема необхідності в таких діях, то залиште це значення як усталено (default).</p>', # MODIF
 	'texte_informations_personnelles_1' => 'Теперь система створить ваш обліковий запис на сайті.',
 	'texte_informations_personnelles_2' => '(Примітка: Якщо ви перевстановлюєте SPIP і ваш старий логін і пароль як і раніше працюють, ви можете',
 	'texte_introductif_article' => '(Вступний текст до статті)',
@@ -766,7 +774,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'texte_jeu_caractere_4' => 'Якщо це не відповідає ситуації з вашими даними (наприклад, після відновлення бази даних з резервної копії), або якщо <em>ви створюєте цей сайт</em> і хочете використовувати різні набори символів, будь ласка, вкажіть набор символів тут:',
 	'texte_login_ldap_1' => '(Залиште порожнім для анонімного доступу або введіть повний шлях, наприклад «<tt>uid=smith, ou=users, dc=my-domain, dc=com </tt>».)',
 	'texte_login_precaution' => 'Увага! Це ваш поточний логін на сайті, міняйте вдумливо.',
-	'texte_messagerie_agenda' => 'Система відправлення повідомлень дозволяє авторам сайту спілкуватися безпосередньо в редакційній частині сайту. Вона пов’язана з календарем.',
+	'texte_messagerie_agenda' => 'Система відправлення повідомлень дозволяє авторам сайту спілкуватися безпосередньо в редакційній частині сайту. Вона пов’язана з календарем.', # MODIF
 	'texte_mise_a_niveau_base_1' => 'Ви тільки но поновили файли SPIP. Теперь ви повинні поновити базу даних сайту.',
 	'texte_modifier_article' => 'Змінити статтю:',
 	'texte_multilinguisme' => 'Якщо на сайті будуть розміщуватися матеріали деякільками мовами, ви можете додати «меню вибору мови» для цих матеріалів.',
@@ -807,11 +815,10 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'texte_titre_02' => 'Заголовок:',
 	'texte_titre_obligatoire' => '<b>Заголовок</b> [обов’язково]',
 	'texte_travail_article' => '@nom_auteur_modif@ роботав над цією статтею @date_diff@ хвилин тому',
-	'texte_travail_collaboratif' => 'Якщо декілька авторів редагують одну і ту ж саму статтю, то система позначає її як «в роботі» і обмежує доступ до неї, щоб уникнути втрат інформації внаслідок одночасного редагування матеріалу. Зазвичай цю можливість відключено.',
+	'texte_travail_collaboratif' => 'Якщо декілька авторів редагують одну і ту ж саму статтю, то система позначає її як «в роботі» і обмежує доступ до неї, щоб уникнути втрат інформації внаслідок одночасного редагування матеріалу. Зазвичай цю можливість відключено.', # MODIF
 	'texte_vide' => 'очистити',
 	'texte_vider_cache' => 'Очистити кеш',
 	'titre_admin_tech' => 'Технічне обслуговування',
-	'titre_admin_vider' => 'Технічне обслуговування',
 	'titre_ajouter_un_auteur' => 'Додати автора',
 	'titre_ajouter_un_mot' => 'Додати ключове слово',
 	'titre_cadre_afficher_article' => 'Показати статті:',
@@ -864,5 +871,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'utf8_convert_erreur_orig' => 'Помилка: набір символів @charset@ не підтримується.',
 
 	// V
-	'version' => 'Версія:'
-);
+	'version' => 'Версія:',
+];
