@@ -1,13 +1,9 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
-// extrait automatiquement de https://trad.spip.net/tradlang_module/spip?lang_cible=ar
+// extrait automatiquement de https://trad.spip.net/tradlang_module/spip_?lang_cible=ar
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'access_interface_graphique' => 'عودة إلى الواجهة الرسومية الكاملة',
@@ -276,7 +272,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'form_pet_signature_pasprise' => 'تم تجاهل توقيعك.',
 	'form_prop_confirmer_envoi' => 'تأكيد الإرسال',
 	'form_prop_description' => 'وصف/تعليق',
-	'form_prop_enregistre' => 'تم تسجيل اقتراحك، سوف يظهر بعد تصديقه من قبل مسئولي هذا الموقع.',
+	'form_prop_enregistre' => 'تم تسجيل اقتراحك، سوف يظهر بعد تصديقه من قبل مسؤولي هذا الموقع.',
 	'form_prop_envoyer' => 'ابعث برسالة',
 	'form_prop_indiquer_email' => 'الرجاء إدخال عنوان بريد إلكتروني صالح',
 	'form_prop_indiquer_nom_site' => 'الرجاء إدخال اسم الموقع.',
@@ -365,7 +361,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_breves_nb' => '@nb@ خبر',
 	'info_breves_un' => 'خبر واحد',
 	'info_connexion_refusee' => 'رفض الاتصال',
-	'info_contact_developpeur' => 'الرجاء الاتصال بمطوّر.',
+	'info_contact_developpeur' => 'الرجاء الاتصال بالأشخاص المولجين بالتطوير.',
 	'info_contenance' => 'هذا الموقع يحتوي على:',
 	'info_contribution' => 'مشاركة منتديات',
 	'info_copyright' => '@spip@ برنامج حر موزع @lien_gpl@.',
@@ -402,7 +398,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_impossible_lire_page' => '<b>خطأ!</b> لا يمكن قراءة الصفحة <tt><html>@test_proxy@</html></tt> عبر الجهاز الوكيل',
 	'info_installation_systeme_publication' => 'تثبيت نظام النشر...',
 	'info_installer_documents' => 'يمكنك تثبيت كل المستندات الموجودة في المجلد @upload@ آلياً.',
-	'info_installer_ftp' => 'بصفتك مديراً، يمكنك تثبيت (بواسطة بروتوكول FTP) ملفات في المجلد@upload@  من أجل تحديدهم في ما بعد مباشرة من هنا.',
+	'info_installer_ftp' => 'بصفتكم مديراً او مديرة، يمكنكم تثبيت (بواسطة بروتوكول FTP) ملفات في المجلد@upload@  من أجل تحديدهم في ما بعد مباشرة من هنا.',
 	'info_installer_images' => 'يمكنك تثبيت صور بتنسيقات JPEG  وGIF  وPNG.',
 	'info_installer_images_dossier' => 'تثبيت صور في المجلد @upload@  للتمكن من تحديدها هنا.',
 	'info_interface_complete' => 'واجهة كاملة',
@@ -430,8 +426,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_multi_herit' => 'اللغة الافتراضية',
 	'info_multi_langues_soulignees' => '<u>اللغات التي تحتها خط</u> تتمتع بترجمة كاملة او جزئية لكل نصوص الواجهة. فإذا حددت هذه اللغات، سيتم ترجمة العديد من عناصر الموقع العمومي (التواريخ والاستمارات) آلياً. أما بالنسبة للغات التي ليس تحتها خط، فستظهر هذه العناصر في لغة الموقع الأساسية.',
 	'info_multilinguisme' => 'تعدد اللغات',
-	'info_nom_non_utilisateurs_connectes' => 'اسمك لا يظهر في قائمة المستخدمين المتصلين.',
-	'info_nom_utilisateurs_connectes' => 'اسمك يظهر في قائمة المستخدمين المتصلين.',
+	'info_nom_non_utilisateurs_connectes' => 'اسمك لا يظهر في قائمة الأشخاص المتصلين.',
+	'info_nom_utilisateurs_connectes' => 'اسمك يظهر في قائمة الأشخاص المتصلين.',
 	'info_nombre_en_ligne' => 'متصل حالياً:',
 	'info_non_resultat' => 'لا توجد نتائج لـ "@cherche_mot@"',
 	'info_non_utilisation_messagerie' => 'أنت لا تستخدم المراسلة الداخلية في هذا الموقع.',
@@ -470,8 +466,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_sites_un' => 'موقع واحد',
 	'info_supprimer_vignette' => 'حذف المصغر',
 	'info_symbole_bleu' => 'الرمز <b>أزرق</b> يرمز إلى <b>مذكرة</b>: أي رسالة لاستخدامك الشخصي.',
-	'info_symbole_jaune' => 'الرمز <b>أصفر</b> يرمز إلى <b>إعلان لجميع المحررين</b>: يمكن لجميع المدراء تحريره وهو ظاهر لجميع المحررين.',
-	'info_symbole_vert' => 'الرمز <b>أخضر</b>  يرمز إلى <b>الرسائل المتبادلة بين مستخدمي</b> الموقع.',
+	'info_symbole_jaune' => 'الرمز <b>أصفر</b> يرمز إلى <b>إعلان لجميع المحررين والمحررات</b>: يمكن لجميع المدراء والمديرات تحريره وهو ظاهر للجميع.',
+	'info_symbole_vert' => 'الرمز <b>أخضر</b>  يرمز إلى <b>الرسائل المتبادلة مع أشخاص آخرين</b> الموقع.',
 	'info_telecharger_nouveau_logo' => 'تحميل رمز جديد:',
 	'info_telecharger_ordinateur' => 'تحميل من جهازك:',
 	'info_tous_resultats_enregistres' => '[تم تسجيل كل النتائج]',
@@ -558,6 +554,12 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 	// N
 	'navigateur_pas_redirige' => 'إذا لم تتم إعادة توجيه متصفحك، انقر هنا للمتابعة.',
+	'notification_mise_a_jour' => 'مرحبا،
+
+يمكن ترقية الموقع @adresse_site@ الى إصدار جديد من SPIP.
+
+من المهم اعتماد الموقع على احدث إصدار لتفادي مشاكل الأمان. 
+', # MODIF
 	'numero' => 'رقم',
 
 	// O
@@ -582,9 +584,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'pass_erreur_non_enregistre' => '<b>خطأ:< b>  العنوان <tt>@email_oubli@</tt> ليس مسجلاً في هذا الموقع.',
 	'pass_erreur_non_valide' => '<b>خطأ:< b>  العنوان <tt>@email_oubli@</tt> ليس صالحاً.',
 	'pass_erreur_probleme_technique' => '<b>خطأ:< b>  لم يتم بعث هذه الرسالة بسبب مشكلة تقنية.',
-	'pass_espace_prive_bla' => 'المجال الخاص لهذا الموقع مفتوح
-للزوار بعد تسجيلهم. بعد تسجيلك
-يمكنك مراجعة المقالات قيد التحرير
+	'pass_espace_prive_bla' => 'المجال الخاص لهذا الموقع مفتوح للزوار بعد تسجيلهم. بعد تسجيلكم
+يمكنكم مراجعة المقالات قيد التحرير
 واقتراح مقالات والمشاركة في كل المنتديات.',
 	'pass_forum_bla' => 'طلبت المشاركة في منتدى
 محصور بالزوار المسجلين.',
@@ -594,7 +595,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 استعادة دخولك.',
 	'pass_mail_passcookie' => '(هذه رسالة آلية)
 لاستعادة دخولك إلى الموقع
-@nom_site_spip@  (@adresse_site@)
+@nom_site_spip@  @adresse_site@
 
 الرجاء الذهاب إلى العنوان التالي:
 
@@ -665,7 +666,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 التأقلم مع نظام SPIP  للنشر. <br /><br /><b>بشكل
 عام، ننصحك
 بحصر التعامل مع هذه الصفحات بالمسؤول الأساسي عن تصميم الموقع.</b>',
-	'texte_inc_meta_1' => 'واجه النظام خطأً خلال كتابة الملف <code>@fichier@</code>. بصفتك أحد مدراء الموقع، الرجاء',
+	'texte_inc_meta_1' => 'واجه النظام خطأً خلال كتابة الملف <code>@fichier@</code>. بصفتكم من مدراء ومديرات الموقع، الرجاء',
 	'texte_inc_meta_2' => 'التأكد من حقوق الكتابة',
 	'texte_inc_meta_3' => 'الخاصة بالدليل <code>@repertoire@</code>. ',
 	'texte_statut_en_cours_redaction' => 'قيد التحرير',
@@ -677,7 +678,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'titre_cadre_raccourcis' => 'اختصارات:',
 	'titre_changer_couleur_interface' => 'تغيير لون الواجهة',
 	'titre_image_admin_article' => 'أنت مخول إدارة هذا المقال',
-	'titre_image_administrateur' => 'مدير',
+	'titre_image_administrateur' => 'مدير ومديرة',
 	'titre_image_aide' => 'تعليمات حول هذا العنصر',
 	'titre_image_auteur_supprime' => 'مؤلف محذوف',
 	'titre_image_redacteur' => 'محرر دون إذن دخول',
@@ -730,6 +731,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'zbug_pagination_sans_critere' => 'علامة PAGINATION# بدون معيار {pagination} أو مستخدمة في حلقة دورية',
 	'zbug_parametres_inclus_incorrects' => 'عامل إدراج غير صحيحة: @param@',
 	'zbug_profile' => 'فترة المعالجة: @time@',
+	'zbug_profile_nb' => 'عدد الحساب: @nb@',
+	'zbug_profile_total' => 'الوقت الإجمالي: @time@',
 	'zbug_resultat' => 'النتيجة',
 	'zbug_serveur_indefini' => 'خادم SQL غير محدد',
 	'zbug_statistiques' => 'احصاءات استفسارات SQL مرتبة حسب المدة',
@@ -749,5 +752,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'zxml_survoler' => 'الحوم لعرض الصحيح',
 	'zxml_valeur_attribut' => 'قيمة الخاصية',
 	'zxml_vide_balise' => 'علامة فارغة',
-	'zxml_vu' => 'ظهر مسبقاً'
-);
+	'zxml_vu' => 'ظهر مسبقاً',
+];
