@@ -1,13 +1,9 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
-// extrait automatiquement de https://trad.spip.net/tradlang_module/spip?lang_cible=bg
+// extrait automatiquement de https://trad.spip.net/tradlang_module/spip_?lang_cible=bg
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'access_interface_graphique' => 'Обратно към пълния графичен интерфейс',
@@ -202,7 +198,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'form_pet_signature_pasprise' => 'Грешен запис',
 	'form_prop_confirmer_envoi' => 'Потвърждение на изпращането',
 	'form_prop_description' => 'Описание/коментар',
-	'form_prop_enregistre' => 'Вашето предложение е записано. То ще се появи на страниците на сайта след одобрение от администратор. ',
+	'form_prop_enregistre' => 'Вашето предложение е записано. То ще се появи на страниците на сайта след одобрение от администратор. ', # MODIF
 	'form_prop_envoyer' => 'Изпращане на съобщение',
 	'form_prop_indiquer_email' => 'Попълнете валиден електронен адрес (e-mail)',
 	'form_prop_indiquer_nom_site' => 'Попълнете името на сайта.',
@@ -282,7 +278,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_authentification_ftp' => 'Удостоверяване автентичността (чрез FTP).',
 	'info_breves_2' => 'новини',
 	'info_connexion_refusee' => 'Забранено свързване',
-	'info_contact_developpeur' => 'Моля, свържете се с някой разработчик.',
+	'info_contact_developpeur' => 'Моля, свържете се с някой разработчик.', # MODIF
 	'info_contenance' => 'Сайтът съдържа:',
 	'info_contribution' => 'принос от съобщения във форума', # MODIF
 	'info_copyright' => '@spip@ е свободен софтуер, разпространяван @lien_gpl@.',
@@ -316,7 +312,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_impossible_lire_page' => '<<b>Грешка!</b> Страницата <tt><html>@test_proxy@</html></tt> не се чете през проксито <tt>',
 	'info_installation_systeme_publication' => 'Инсталация на системата за публикуване ...',
 	'info_installer_documents' => 'Можете автоматично да качвате всички документи от следната папка @upload@.',
-	'info_installer_ftp' => 'Като администратор можете да качите файлове (чрез FTP) в папката @upload@, за да ги използвате направо от там, когато Ви потрябват по-късно.',
+	'info_installer_ftp' => 'Като администратор можете да качите файлове (чрез FTP) в папката @upload@, за да ги използвате направо от там, когато Ви потрябват по-късно.', # MODIF
 	'info_installer_images' => 'Форматът на изображенията може да е JPEG, GIF и PNG.',
 	'info_installer_images_dossier' => 'Качете изображения в папка @upload@, за да можете да ги използвате направо от там, когато Ви потрябват по-късно.',
 	'info_interface_complete' => 'Пълен интерфейс',
@@ -342,8 +338,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_multi_herit' => 'Език по подразбиране',
 	'info_multi_langues_soulignees' => '<u>Подчертаните езици</u> осигуряват превод на всички текстове на интерфейса. Ако изберете тези езици, много от елементите на публичния сайт (дати, форми) ще бъдат автоматично преведени. Колкото до неподчертаните езици, елементите ще се появят на основния език за този сайт.', # MODIF
 	'info_multilinguisme' => 'Многоезичен',
-	'info_nom_non_utilisateurs_connectes' => 'Името Ви е изключено от списъка на свързаните към Интернет потребители',
-	'info_nom_utilisateurs_connectes' => 'Името Ви е добавено в списъка на свързаните към Интернет потребители',
+	'info_nom_non_utilisateurs_connectes' => 'Името Ви е изключено от списъка на свързаните към Интернет потребители', # MODIF
+	'info_nom_utilisateurs_connectes' => 'Името Ви е добавено в списъка на свързаните към Интернет потребители', # MODIF
 	'info_nombre_en_ligne' => 'Текущо са в мрежата:',
 	'info_non_resultat' => 'Няма намерени резултати за @cherche_mot@',
 	'info_non_utilisation_messagerie' => 'Не използвате системата за вътешни съобщения на този сайт.',
@@ -375,8 +371,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_selectionner_fichier_2' => 'Изберете файл:',
 	'info_supprimer_vignette' => 'изтриване на винетката',
 	'info_symbole_bleu' => 'Символът <b>синьо</b> указва <b>бележка</b>: т.е. съобщение за лично ползване.',
-	'info_symbole_jaune' => 'Символът <b>жълто</b> указва  <b>съобщение към всички редактори</b>: то може да се вписва само от администратори и да се вижда от всички редактори.',
-	'info_symbole_vert' => 'Символът <b>зелено</b> указва <b>съобщения, обменени с други потребители</b> на сайта.',
+	'info_symbole_jaune' => 'Символът <b>жълто</b> указва  <b>съобщение към всички редактори</b>: то може да се вписва само от администратори и да се вижда от всички редактори.', # MODIF
+	'info_symbole_vert' => 'Символът <b>зелено</b> указва <b>съобщения, обменени с други потребители</b> на сайта.', # MODIF
 	'info_telecharger_nouveau_logo' => 'Качване на ново лого:',
 	'info_telecharger_ordinateur' => 'Качете от своя компютър на сайта:',
 	'info_tous_resultats_enregistres' => '[всички резултати са записани]',
@@ -467,16 +463,16 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'pass_choix_pass' => 'Изберете нова парола:',
 	'pass_erreur' => 'Грешка',
 	'pass_erreur_acces_refuse' => '<b>Грешка:</b> нямате повече достъп до този сайт.',
-	'pass_erreur_code_inconnu' => '<b>Грешка:</b> този код не съвпада с никой посетител, който има разрешение за достъп до сайта.',
+	'pass_erreur_code_inconnu' => '<b>Грешка:</b> този код не съвпада с никой посетител, който има разрешение за достъп до сайта.', # MODIF
 	'pass_erreur_non_enregistre' => '<b>Грешка:</b> адресът <tt>@email_oubli@</tt> не е регистриран в сайта.',
 	'pass_erreur_non_valide' => '<b>Грешка:</b> електронният адрес <tt>@email_oubli@</tt> е погрешен!',
 	'pass_erreur_probleme_technique' => '<b>Грешка:</b> това писмо не може да бъде изпратено поради технически проблем.',
 	'pass_espace_prive_bla' => 'Личната зона на сайта е отворена само за
 регистирани посетители. След като се регистрирате,
 можете да преглеждате статиите, които са в
-в процес на обработка, да изпращате статии и да участвате във всички форуми.',
+в процес на обработка, да изпращате статии и да участвате във всички форуми.', # MODIF
 	'pass_forum_bla' => 'Пожелали сте да участвате във форум, който
-е запазен за регистрирани посетители.',
+е запазен за регистрирани посетители.', # MODIF
 	'pass_indiquez_cidessous' => 'Попълнете електронният адрес, с който
 сте регистрирани.
 Ще получите писмо с инструкции за това, как
@@ -491,7 +487,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 След това можете да смените паролата
 и да се свържете към сайта отново.
-',
+', # MODIF
 	'pass_mot_oublie' => 'Забравена парола',
 	'pass_nouveau_enregistre' => 'Новата Ви парола бе запазена.',
 	'pass_nouveau_pass' => 'Нова парола',
@@ -540,7 +536,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'texte_inc_auth_3' => 'след като излезете
   презаредете навигатора си, ако се налага.',
 	'texte_inc_config' => 'Промените, които са направени по-долу оказват изключително голямо влияние на работата на сайта. Съветваме Ви да не ги пипате, освен ако не сте добре запознати с работата на системата СПИП. <br /><br /><b>Силно  Ви препоръчваме да оставите главния уеб администратор да работи с тази страница.</b>',
-	'texte_inc_meta_1' => 'Системата намери грешка при опит за запис във файла <code>@fichier@</code>. Като администратор на сайта, моля да направите ',
+	'texte_inc_meta_1' => 'Системата намери грешка при опит за запис във файла <code>@fichier@</code>. Като администратор на сайта, моля да направите ', # MODIF
 	'texte_inc_meta_2' => 'проверка на позволенията за запис',
 	'texte_inc_meta_3' => 'на директорията <code>@repertoire@</code>.',
 	'texte_statut_en_cours_redaction' => 'в процес на обработка',
@@ -552,7 +548,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'titre_cadre_raccourcis' => 'КОМАНДИ ЗА УСКОРЕН ДОСТЪП:',
 	'titre_changer_couleur_interface' => 'Смяна цвета на интерфейса',
 	'titre_image_admin_article' => 'Администриране на статията',
-	'titre_image_administrateur' => 'Администратор',
+	'titre_image_administrateur' => 'Администратор', # MODIF
 	'titre_image_aide' => 'Помощник за тази част',
 	'titre_image_auteur_supprime' => 'Авторът е изтрит',
 	'titre_image_redacteur' => 'Редактор без достъп',
@@ -587,5 +583,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'zbug_parametres_inclus_incorrects' => 'Погрешни параметри за включване', # MODIF
 	'zbug_resultat' => 'резултат',
 	'zbug_serveur_indefini' => 'неопределен сървър SQL', # MODIF
-	'zbug_table_inconnue' => 'Непозната таблица от типа SQL: "@table@"'
-);
+	'zbug_table_inconnue' => 'Непозната таблица от типа SQL: "@table@"',
+];
