@@ -1,13 +1,9 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
-// extrait automatiquement de https://trad.spip.net/tradlang_module/spip?lang_cible=fa
+// extrait automatiquement de https://trad.spip.net/tradlang_module/spip_?lang_cible=fa
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'access_interface_graphique' => 'بازگشت به نماى كامل سايت',
@@ -266,7 +262,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'form_pet_signature_pasprise' => '.امضاء تان قبول نشده',
 	'form_prop_confirmer_envoi' => 'تأئيد فرستادن',
 	'form_prop_description' => 'توصيف/تفسير',
-	'form_prop_enregistre' => 'پيشنهاد شما ثبت شد، پس از تأئيد مسئولان سايت بروى سايت خواهد رفت',
+	'form_prop_enregistre' => 'پيشنهاد شما ثبت شد، پس از تأئيد مسئولان سايت بروى سايت خواهد رفت', # MODIF
 	'form_prop_envoyer' => 'يك پيام بفرستيد',
 	'form_prop_indiquer_email' => 'خواهشمند است كه يك آدرس ايميل معتبر را مشخص كنيد',
 	'form_prop_indiquer_nom_site' => 'خواهشمند است نام سايت را مشخص كنيد',
@@ -351,7 +347,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_breves_nb' => '@nb@ خبر',
 	'info_breves_un' => 'خبر 1',
 	'info_connexion_refusee' => 'ارتباط پذيرفته نشد',
-	'info_contact_developpeur' => '.خواهشمند است كه با يك برنامه نويس تماس بگيريد',
+	'info_contact_developpeur' => '.خواهشمند است كه با يك برنامه نويس تماس بگيريد', # MODIF
 	'info_contenance' => ': اين سايت حاوى',
 	'info_contribution' => 'نوشته‌ها',
 	'info_copyright' => '@spip@ يك نرم افزار آزاد است  كه @lien_gpl@ توزيع شده.',
@@ -388,7 +384,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_impossible_lire_page' => '<b>اشتباه !</b> خواندن صفحه <tt><html>@test_proxy@</html></tt> با پروكسى غير ممكن ميباشد',
 	'info_installation_systeme_publication' => '...استقرار سيستم نشر',
 	'info_installer_documents' => 'شما ميتوانيد بطور خودكار تمام مطالب پرونده را نصب كنيد @upload@.',
-	'info_installer_ftp' => 'بعنوان گرداننده سايت، شما ميتوانيد فايلهاى درون پرونده @upload@ را مستقر كنيد سپس آنها را مستقيمأ در اينجا انتخاب كنيد. ',
+	'info_installer_ftp' => 'بعنوان گرداننده سايت، شما ميتوانيد فايلهاى درون پرونده @upload@ را مستقر كنيد سپس آنها را مستقيمأ در اينجا انتخاب كنيد. ', # MODIF
 	'info_installer_images' => ': شما ميتوانيد اين نوع تصاوير را نصب كنيدJPEG, GIF, PNG',
 	'info_installer_images_dossier' => 'تصاوير درون پرونده @upload@  را مستقر كنيد  تا بتوانيد آنها را مستقيمأ در اينجا انتخاب كنيد. ',
 	'info_interface_complete' => 'نماى كامل',
@@ -416,8 +412,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_multi_herit' => ' زبان اصلی',
 	'info_multi_langues_soulignees' => '<u>زبان‌هاي مشخص شده</u> ترجمه تمام يا بخشي از متن‌هاي نرم‌افزار واسط را ارايه مي‌دهد. اگر اين زبان‌ها را انتخاب كنيد، بعضي از عناصر سايت عمومي (تاريخ‌ها، فرم‌ها) به صورت خود به خودي ترجمه مي‌شود. براي زبان‌هايي كه مشخص نشده‌اند، اين عناصر باز زبان پيش‌گزيده سايت نمايش داده مي‌شوند. ',
 	'info_multilinguisme' => 'چند زبانه گى',
-	'info_nom_non_utilisateurs_connectes' => 'نامتان در فهرست كاربران متصل به تارنما نميباشد',
-	'info_nom_utilisateurs_connectes' => 'نامتان در فهرست كاربران متصل به تارنما ميباشد',
+	'info_nom_non_utilisateurs_connectes' => 'نامتان در فهرست كاربران متصل به تارنما نميباشد', # MODIF
+	'info_nom_utilisateurs_connectes' => 'نامتان در فهرست كاربران متصل به تارنما ميباشد', # MODIF
 	'info_nombre_en_ligne' => ': هم اكنون روى خط',
 	'info_non_resultat' => '"@cherche_mot@" بى نتيجه براى   ',
 	'info_non_utilisation_messagerie' => 'شما از پيامگير داخلى سايت استفاده نميكنيد.',
@@ -455,8 +451,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_sites_un' => 'سايت 1',
 	'info_supprimer_vignette' => 'تصاوير كوچك را حذف كنيد',
 	'info_symbole_bleu' => 'نماد آبى نمايانگر يادداشت است : يا بعبارتى پيام، براى استفاده شخصى.',
-	'info_symbole_jaune' => 'نماد زرد نشانگر یک خبر براى تمام نويسندگان ميباشد : كه قابل اصلاح توسط تمام گردانندگان سايت و قابل رؤيت براى تمام نويسندگان ميباشد.',
-	'info_symbole_vert' => 'نماد سبز نشانگر پيامهاى رد و بدل شده با ديگر كاربران ميباشد.',
+	'info_symbole_jaune' => 'نماد زرد نشانگر یک خبر براى تمام نويسندگان ميباشد : كه قابل اصلاح توسط تمام گردانندگان سايت و قابل رؤيت براى تمام نويسندگان ميباشد.', # MODIF
+	'info_symbole_vert' => 'نماد سبز نشانگر پيامهاى رد و بدل شده با ديگر كاربران ميباشد.', # MODIF
 	'info_telecharger_nouveau_logo' => ':يك لوگوى جديد بارگذارى كنيد',
 	'info_telecharger_ordinateur' => ':با رايانه خودتان بارگذارى كنيد',
 	'info_tous_resultats_enregistres' => '[تمام نتايج ثبت شده اند]',
@@ -550,15 +546,15 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'pass_choix_pass' => 'خواهشمند است كلمه ورودى جديدتان را انتخاب كنيد',
 	'pass_erreur' => 'اشتباه',
 	'pass_erreur_acces_refuse' => '<b>اشتباه :</b>شما به اين سايت ديگر دسترسى نداريد',
-	'pass_erreur_code_inconnu' => '<b>اشتباه :</b> اين كد به هيچيك از بازديدكنندگانى كه به اين سايت دسترسى دارند تعلق ندارد',
+	'pass_erreur_code_inconnu' => '<b>اشتباه :</b> اين كد به هيچيك از بازديدكنندگانى كه به اين سايت دسترسى دارند تعلق ندارد', # MODIF
 	'pass_erreur_non_enregistre' => '<b>اشتباه :</b>اين آدرس در اين سايت ثبت نشده است<tt>@email_oubli@</tt> ',
 	'pass_erreur_non_valide' => '<b>اشتباه :</b>  اين ايميل معتبر نميباشد<tt>@email_oubli@</tt> ',
 	'pass_erreur_probleme_technique' => '<b>اشتباه :</b>بخاطر مشكل فنى نميتوان ايميل را فرستاد',
-	'pass_espace_prive_bla' => 'قسمت خصوصى اين سايت پس از ثبت نام بروى بازديدكنندگان بازخواهد بود. شما ميتوانيد پس از ثبت نام، مقالات در حال نگارش را بخوانيد، همچنين ميتوانيد پيشنهاد مقاله و يا در تمام سخنگاه ها شركت كنيد ',
-	'pass_forum_bla' => 'شما درخواست شركت در سخنگاه مختص بازديدكنندگان ثبت شده را كرديد',
+	'pass_espace_prive_bla' => 'قسمت خصوصى اين سايت پس از ثبت نام بروى بازديدكنندگان بازخواهد بود. شما ميتوانيد پس از ثبت نام، مقالات در حال نگارش را بخوانيد، همچنين ميتوانيد پيشنهاد مقاله و يا در تمام سخنگاه ها شركت كنيد ', # MODIF
+	'pass_forum_bla' => 'شما درخواست شركت در سخنگاه مختص بازديدكنندگان ثبت شده را كرديد', # MODIF
 	'pass_indiquez_cidessous' => 'آدرس ايميلى كه با آن ثبت شده ايد را مشخص كنيد. شما ايميلى دريافت خواهيد كرد كه شامل راهنماى ورودتان ميباشد',
 	'pass_mail_passcookie' => 'اين يك پيام خودكار است.براى دسترسى به سايت@nom_site_spip@ (@adresse_site@)خواهشمند است به اين آدرس مراجعه كنيد :  @sendcookie@
-شما ميتوانيد كلمه ورودى ديگرى را وارد كنيد و دوباره به سايت وصل شويد',
+شما ميتوانيد كلمه ورودى ديگرى را وارد كنيد و دوباره به سايت وصل شويد', # MODIF
 	'pass_mot_oublie' => 'كلمه ورود فراموش شده',
 	'pass_nouveau_enregistre' => 'كلمه ورودى جديدتان ثبت شد.',
 	'pass_nouveau_pass' => 'كلمه ورودى جديد',
@@ -606,7 +602,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'texte_inc_auth_2' => 'دوباره متصل شويد',
 	'texte_inc_auth_3' => 'پس از ترك و راه انداختن مجدد مرورگر. ',
 	'texte_inc_config' => 'تغيير در اين صفحات در عملكرد سايتتان تاثير قابل توجهى بجاى ميگذارد. بشما پيشنهاد ميكنيم اگر با سيستم اسپيپ آشنايى نداريد از  دستكارى آنها بپرهيزيد.<br /><br /><b> توصيه ميشود كه اين وظيفه را به وب مستر اصلى محول كنيد.</b>',
-	'texte_inc_meta_1' => 'سيستم بهنگام نوشتن فايل<code>@fichier@</code> به مشكلى برخورد كرده است, خواهشمند است، بعنوان گرداننده سايت',
+	'texte_inc_meta_1' => 'سيستم بهنگام نوشتن فايل<code>@fichier@</code> به مشكلى برخورد كرده است, خواهشمند است، بعنوان گرداننده سايت', # MODIF
 	'texte_inc_meta_2' => 'حق استفاده را تاييد كنيد',
 	'texte_inc_meta_3' => 'در رپرتوار<code>@repertoire@</code>.',
 	'texte_statut_en_cours_redaction' => 'در حال نگارش',
@@ -618,7 +614,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'titre_cadre_raccourcis' => 'راه كوتاه :',
 	'titre_changer_couleur_interface' => 'رنگ نماى سايت را تغيير دهيد',
 	'titre_image_admin_article' => 'شما ميتوانيد اين مقاله را اداره كنيد',
-	'titre_image_administrateur' => 'گرداننده سايت',
+	'titre_image_administrateur' => 'گرداننده سايت', # MODIF
 	'titre_image_aide' => 'كمك براى اين قسمت',
 	'titre_image_auteur_supprime' => 'نويسنده حذف شده',
 	'titre_image_redacteur' => 'نويسنده بدون حق دسترسى',
@@ -683,5 +679,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'zxml_survoler' => 'برای دیدن جوابهای صحیح نوک فلش را روی آنها بگذارید',
 	'zxml_valeur_attribut' => 'ارزش مشخصه ها',
 	'zxml_vide_balise' => 'TAG خالی',
-	'zxml_vu' => 'قبلأ دیده شده'
-);
+	'zxml_vu' => 'قبلأ دیده شده',
+];
