@@ -252,7 +252,6 @@ sera ignorée) :
 	'form_email_non_valide' => 'Votre adresse email n’est pas valide.',
 	'form_forum_access_refuse' => 'Vous n’avez plus accès à ce site.',
 	'form_forum_bonjour' => 'Bonjour @nom@,',
-	'form_forum_confirmer_email' => 'Pour confirmer votre adresse email, rendez-vous à cette adresse : @url_confirm@',
 	'form_forum_email_deja_enregistre' => 'Cette adresse email est déjà enregistrée, vous pouvez donc utiliser votre mot de passe habituel.',
 	'form_forum_identifiant_mail' => 'Votre nouvel identifiant vient de vous être envoyé par email.',
 	'form_forum_identifiants' => 'Identifiants personnels',
@@ -613,6 +612,7 @@ et vous reconnecter au site.
 	'pass_quitter_fenetre' => 'Quitter cette fenêtre',
 	'pass_rappel_login' => 'Rappel : votre identifiant (login) est « @login@ ».',
 	'pass_recevoir_mail' => 'Un lien de réinitialisation de votre mot de passe vous a été envoyé sur votre adresse email (si celle-ci est valide).',
+	'pass_reset_url' => 'mot de passe à définir ou modifier en vous rendant sur @url@',
 	'pass_retour_public' => 'Retour sur le site public',
 	'pass_rien_a_faire_ici' => 'Rien à faire ici.',
 	'pass_vousinscrire' => 'Vous inscrire sur ce site',
