@@ -1,13 +1,9 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
-// extrait automatiquement de https://trad.spip.net/tradlang_module/spip?lang_cible=km
+// extrait automatiquement de https://trad.spip.net/tradlang_module/spip_?lang_cible=km
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'access_interface_graphique' => 'ត្រលប់​ទៅ ផ្ទាំង​ប្រទាក់​ក្រាហ្វិក​ពេញលេញ​',
@@ -230,7 +226,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'form_pet_signature_pasprise' => 'ហត្ថលេខា ​របស់​អ្នក ត្រូវ​បាន​បដិសេធ ។',
 	'form_prop_confirmer_envoi' => 'បញ្ជាក់​ទទួលស្គាល់ បញ្ញើ',
 	'form_prop_description' => 'ការពិពណ៌នា/វិចារ',
-	'form_prop_enregistre' => 'បានចុះបញ្ជី សំណើរ​ របស់​អ្នក​, វា​នឹង​លេច​ចេញ ​លើ​អិនរើណែត បន្ទាប់ពីមាន​សុពលភាព ​ដោយ​អ្នកអភិបាលវ៉ែបសៃថ៍នេះ។',
+	'form_prop_enregistre' => 'បានចុះបញ្ជី សំណើរ​ របស់​អ្នក​, វា​នឹង​លេច​ចេញ ​លើ​អិនរើណែត បន្ទាប់ពីមាន​សុពលភាព ​ដោយ​អ្នកអភិបាលវ៉ែបសៃថ៍នេះ។', # MODIF
 	'form_prop_envoyer' => 'ផ្ញើ​ មួយសារ',
 	'form_prop_indiquer_email' => 'សូម​បញ្ចូល​ មួយអាសយដ្ឋាន​អ៊ីមែវល៍​ ដែល​មាន​សុពលភាព ។',
 	'form_prop_indiquer_nom_site' => 'សូម​បញ្ចូល​ឈ្មោះ​ របស់​វ៉ែបសៃថ៍។',
@@ -310,7 +306,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_authentification_ftp' => 'ធ្វើអោយត្រឹមត្រូវ តាមភាពដើម (​ដោយ FTP)។',
 	'info_breves_2' => 'ពត៌មានសង្ខេប',
 	'info_connexion_refusee' => 'បញ្ជាប់ ​ត្រូវ​បាន​បដិសេធ',
-	'info_contact_developpeur' => '​ទាក់ទង​ អ្នក​អភិវឌ្ឍ។',
+	'info_contact_developpeur' => '​ទាក់ទង​ អ្នក​អភិវឌ្ឍ។', # MODIF
 	'info_contenance' => 'វ៉ែបសៃថ៍ នេះ​មានផ្ទុក ៖',
 	'info_contribution' => 'ការ​រួមចំណែក នៃ​វេទិកា', # MODIF
 	'info_copyright' => '@spip@ ជា​ផ្នែកទន់សេរី ត្រូវបានបែងចែក ​ដោយ @lien_gpl@។',
@@ -344,7 +340,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_impossible_lire_page' => '<b>​កំហុស​!</b> គ្មានអាចអានទំព័រ<tt><html>@test_proxy@</html></tt> ​តាម​ខំព្យូរើបំរើសេវា Proxy',
 	'info_installation_systeme_publication' => 'ការ​តំលើង ​ប្រ​ព័ន្ធផ្សព្វផ្សាយ​...',
 	'info_installer_documents' => 'អ្នក​អាចតំលើង ​ស្វ័យប្រវត្ដិ​ គ្រប់ឯកសារ ដែល​មានផ្ទុក ​ក្នុង​ថត​ឯកសារ​@upload@។',
-	'info_installer_ftp' => 'ក្នុង​នាម​ជា ​អ្នកអភិបាល, អ្នក​អាចតំលើង (​តាមខំព្យូរើបំរើសេវា FTP) សំណុំឯកសារ ​ក្នុង​ថត​ឯកសារ @upload@ ដើម្បី​បន្ត ជ្រើសយកដោយផ្ទាល់ ពួកវា នៅទីនេះ។',
+	'info_installer_ftp' => 'ក្នុង​នាម​ជា ​អ្នកអភិបាល, អ្នក​អាចតំលើង (​តាមខំព្យូរើបំរើសេវា FTP) សំណុំឯកសារ ​ក្នុង​ថត​ឯកសារ @upload@ ដើម្បី​បន្ត ជ្រើសយកដោយផ្ទាល់ ពួកវា នៅទីនេះ។', # MODIF
 	'info_installer_images' => 'អ្នក​អាច​តំលើង រូបភាព​ មានទ្រង់ទ្រាយ .JPEG, .GIF និង .PNG។',
 	'info_installer_images_dossier' => 'តំលើង​រូបភាព ​ក្នុង​ថត​ឯកសារ @upload@ ដើម្បី​អាច​ជ្រើសយកពួកវា នៅទី​នេះ។',
 	'info_interface_complete' => 'ផ្ទាំង​ប្រទាក់ ​ពេញលេញ',
@@ -370,8 +366,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_multi_herit' => 'ភាសា​ លំនាំដើម',
 	'info_multi_langues_soulignees' => '<u>​ភាសា​ ដែល​បាន​គូរ​បន្ទាត់​ក្រោម​</u> ទទួលបានបំណកប្រែ​ គ្រប់អត្ថបទ នៃផ្ទាំង​ប្រទាក់។ បើ​អ្នក​ជ្រើស​យក ​ភាសា​ទាំងនេះ, មាន​ច្រើនធាតុ ​នៃ​សៃថ៍សាធារណះ (​ថ្ងៃខែឆ្នាំ, បែបបទ​) នឹង​ត្រូវបាន​ប្រែ​សំរួល​ស្វ័យប្រវត្ដិ ។ ចំពោះ​ភាសា​ គ្មានគូសបន្ទាត់ក្រោម, ធាតុ​ទាំងនោះ​ នឹង​លេច​ចេញ​ជា​ភាសាលំនាំដើម ​នៃ​សៃថ៍។', # MODIF
 	'info_multilinguisme' => '​ពហុ​ភាសា',
-	'info_nom_non_utilisateurs_connectes' => 'ឈ្មោះ​របស់​អ្នក​ មិន​លេច​ចេញ ​ក្នុង​បញ្ជី​អ្នក​ប្រើ​ប្រាស់​ ដែល​បាន​ភ្ជាប់ ។',
-	'info_nom_utilisateurs_connectes' => 'ឈ្មោះ​របស់​អ្នក​ លេច​ចេញ​ ​ក្នុង​បញ្ជី​អ្នក​ប្រើប្រាស់​ដែល​បាន​​ភ្ជាប់។',
+	'info_nom_non_utilisateurs_connectes' => 'ឈ្មោះ​របស់​អ្នក​ មិន​លេច​ចេញ ​ក្នុង​បញ្ជី​អ្នក​ប្រើ​ប្រាស់​ ដែល​បាន​ភ្ជាប់ ។', # MODIF
+	'info_nom_utilisateurs_connectes' => 'ឈ្មោះ​របស់​អ្នក​ លេច​ចេញ​ ​ក្នុង​បញ្ជី​អ្នក​ប្រើប្រាស់​ដែល​បាន​​ភ្ជាប់។', # MODIF
 	'info_nombre_en_ligne' => 'បច្ចុប្បន្ន កំពុងលើអិនរើណែត ៖',
 	'info_non_resultat' => 'គ្មាន​លទ្ធផល​ សំរាប់ "@cherche_mot@"',
 	'info_non_utilisation_messagerie' => 'អ្នក​មិន​​ប្រើប្រាស់​ បញ្ញើ​សារ​ ខាង​ក្នុងវ៉ែបសៃថ៍ នេះ​។',
@@ -404,8 +400,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_selectionner_fichier_2' => 'ជ្រើសយក មួយឯកសារ ៖',
 	'info_supprimer_vignette' => 'លុប​ចេញ កូនរូបភាព',
 	'info_symbole_bleu' => 'A <b>​និមិត្ដសញា​</b> ពណ៌​ខៀវ<b>​ ​បង្ហាញការរំលឹក</b>៖ មានន័យថា មួយសារសំរាប់​បំរើប្រាស់​ផ្ទាល់ខ្លួន​ របស់​អ្នក ។',
-	'info_symbole_jaune' => 'A <b>​និមិត្ដសញា​</b> ពណ៌​លឿង​<b>​បង្ហាញ មួយជំនូនដំណឹង​ ទៅគ្រប់អ្នកតែងអត្ថបទ </b>៖ ​អាចកែប្រែ ដោយគ្រប់អ្នកអភិបាល, និង អាចឃើញ ដោយគ្រប់អ្នកតែងអត្ថបទ។',
-	'info_symbole_vert' => '​និមិត្ដសញា​<b>ពណ៌​បៃតង​</b> បង្ហាញ <b>បណ្តូរសារ ជាមួយ​អ្នកប្រើប្រាស់ដទៃ</b> នៃវ៉ែបសៃថ៍។',
+	'info_symbole_jaune' => 'A <b>​និមិត្ដសញា​</b> ពណ៌​លឿង​<b>​បង្ហាញ មួយជំនូនដំណឹង​ ទៅគ្រប់អ្នកតែងអត្ថបទ </b>៖ ​អាចកែប្រែ ដោយគ្រប់អ្នកអភិបាល, និង អាចឃើញ ដោយគ្រប់អ្នកតែងអត្ថបទ។', # MODIF
+	'info_symbole_vert' => '​និមិត្ដសញា​<b>ពណ៌​បៃតង​</b> បង្ហាញ <b>បណ្តូរសារ ជាមួយ​អ្នកប្រើប្រាស់ដទៃ</b> នៃវ៉ែបសៃថ៍។', # MODIF
 	'info_telecharger_nouveau_logo' => 'ផ្ទុក​ឡើង​ មួយរូប​សញ្ញា​ថ្មី ៖',
 	'info_telecharger_ordinateur' => 'ផ្ទុក​ឡើង​ ពីខំព្យូរើ របស់​អ្នក ៖',
 	'info_tous_resultats_enregistres' => '[​គ្រប់លទ្ធផល ត្រូវ​បាន​រក្សាទុក]',
@@ -496,19 +492,19 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'pass_choix_pass' => 'ជ្រើសរើស​ ពាក្យសំងាត់​ថ្មី​ របស់​អ្នក៖',
 	'pass_erreur' => 'កំហុស',
 	'pass_erreur_acces_refuse' => '<b>​កំហុស ៖</b> អ្នក​មិន​ចូល​ទៀត ទៅវ៉ែបសៃថ៍នេះ។',
-	'pass_erreur_code_inconnu' => '<b>​កំហុស ៖</b> អក្សរ​កូដ​នេះ​ មិន​ត្រូវ​នឹង​អ្នក​ទស្សនា​ណាមួយ ​ដែល​មានសិទ្ធិចូលទៅ វ៉ែបសៃថ៍នេះ។',
+	'pass_erreur_code_inconnu' => '<b>​កំហុស ៖</b> អក្សរ​កូដ​នេះ​ មិន​ត្រូវ​នឹង​អ្នក​ទស្សនា​ណាមួយ ​ដែល​មានសិទ្ធិចូលទៅ វ៉ែបសៃថ៍នេះ។', # MODIF
 	'pass_erreur_non_enregistre' => '<b>​កំហុស ៖</b> អាសយដ្ឋាន <tt>@email_oubli@</tt> មិន​ត្រូវ​បាន​ចុះ​ឈ្មោះ​លើវ៉ែបសៃថ៍នេះ​។',
 	'pass_erreur_non_valide' => '<b>​កំហុស ៖</b> អ៊ីមែវល៍នេះ<tt>@email_oubli@</tt> គ្មានសុពលភាព!',
 	'pass_erreur_probleme_technique' => '<b>​កំហុសបច្ចេកទេស ៖</b> មិន​អាច​ផ្ញើ​ អ៊ីមែវល៍​នេះ​។',
-	'pass_espace_prive_bla' => 'ទី​ឯកជន ​នៃ​វ៉ែបសៃថ៍នេះ​ ត្រូវចំហ សំរាប់អ្នក​ទស្សនា​, បន្ទាប់ពី​ចុះ​ឈ្មោះ​។ ពេល​បាន​ចុះ​ឈ្មោះ​រួច, អ្នកអាចពិនិត្យមើល អត្ថបទ ដែលកំពុងត្រូវបានតែង, ស្នើអត្ថបទ និង ចូលរួម ទៅគ្រប់វេទិកា។',
-	'pass_forum_bla' => 'អ្នក​បានសួររក ដើម្បីអន្តរាគម លើមួយវេទិកា ដែលទុកសំរាប់ អ្នកទស្សនាបានចំឈ្មោះ។',
+	'pass_espace_prive_bla' => 'ទី​ឯកជន ​នៃ​វ៉ែបសៃថ៍នេះ​ ត្រូវចំហ សំរាប់អ្នក​ទស្សនា​, បន្ទាប់ពី​ចុះ​ឈ្មោះ​។ ពេល​បាន​ចុះ​ឈ្មោះ​រួច, អ្នកអាចពិនិត្យមើល អត្ថបទ ដែលកំពុងត្រូវបានតែង, ស្នើអត្ថបទ និង ចូលរួម ទៅគ្រប់វេទិកា។', # MODIF
+	'pass_forum_bla' => 'អ្នក​បានសួររក ដើម្បីអន្តរាគម លើមួយវេទិកា ដែលទុកសំរាប់ អ្នកទស្សនាបានចំឈ្មោះ។', # MODIF
 	'pass_indiquez_cidessous' => 'បញ្ចូល​ខាងក្រោម​ អាសយដ្ឋាន​អ៊ីមែវល៍​ ដែល​អ្នក​បាន​ចុះ​ឈ្មោះ​ពី​មុន។ អ្នក​នឹង​ទទួល​បាន មួយ​អ៊ីមែវល៍ ​ដែល​ពន្យល់​វិធី​ ដើម្បីសង្គ្រោះការចូលទៅ របស់អ្នក។',
 	'pass_mail_passcookie' => '(​នេះ​ជា មួយ​សារ​ស្វ័យប្រវត្ដិ​)
  ដើម្បីរកមើល ការចូលទៅ របស់អ្នក ក្នុងវ៉ែបសៃថ៍ @nom_site_spip@ (@adresse_site@)
  សូម​ទៅ​អាសយដ្ឋាន បន្តបន្ទាប់៖ 
  @sendcookie@ 
 
-ពេលនោះ អ្នកនឹងអាច បញ្ចូល មួយពាក្យសំងាត់ថ្មី និងអ្នកអាចភ្ជាប់ទៅ វ៉ែបសៃថ៍។',
+ពេលនោះ អ្នកនឹងអាច បញ្ចូល មួយពាក្យសំងាត់ថ្មី និងអ្នកអាចភ្ជាប់ទៅ វ៉ែបសៃថ៍។', # MODIF
 	'pass_mot_oublie' => 'ភ្លេច ពាក្យសំងាត់',
 	'pass_nouveau_enregistre' => 'ពាក្យសំងាត់ថ្មី របស់​អ្នក ​ត្រូវ​បានរក្សាទុក។',
 	'pass_nouveau_pass' => 'ពាក្យសំងាតថ្មី',
@@ -552,7 +548,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'texte_inc_auth_2' => '​ភ្ជាប់​ឡើង​វិញ',
 	'texte_inc_auth_3' => ', បន្ទាប់ពីបានចាកចេញ រួចដំណើរឡើងវិញ ឧបកររាវរក របស់អ្នក។',
 	'texte_inc_config' => 'បំលាស់ប្ដូរ ​ដែល​បានអនុវត្ត ក្នុងទំព័រនេះ មានឥទ្ធិពល គួរកត់សំគាល់ លើដំណើរការ នៃវ៉ែបសៃថ៍ របស់អ្នក។ យើងអនុសាសអ្នក មិនត្រូវអន្តរាគមក្នុងនោះ បើអ្នកមិនជា គ្រួសារ នៃប្រព័ន្ធការងារ SPIP។ <br /><br /><b> លើសពីហ្នឹង, ជា​ទូទៅ សំណូមពរ ប្រគល់ភារ៖កិច្ច ផ្ទុកទំព័រនេះ អោយទៅអ្នកជំនាញវ៉ែប នៃវ៉ែបសៃថ៍ របស់អ្នក។ </b>',
-	'texte_inc_meta_1' => 'ប្រព័ន្ធ​ បានជួបមួយកំហុស ពេលសរសេរ លើសំណុំឯកសារ <code>@fichier@</code>។ ក្នុង​នាម​ជា​អ្នកអភិបាលសៃថ៍, សូម',
+	'texte_inc_meta_1' => 'ប្រព័ន្ធ​ បានជួបមួយកំហុស ពេលសរសេរ លើសំណុំឯកសារ <code>@fichier@</code>។ ក្នុង​នាម​ជា​អ្នកអភិបាលសៃថ៍, សូម', # MODIF
 	'texte_inc_meta_2' => 'ផ្ទៀងផ្ទាត់ សិទ្ធិសរសេរ',
 	'texte_inc_meta_3' => 'លើបញ្ជី​រាយ​ឈ្មោះ <code>@repertoire@</code>។',
 	'texte_statut_en_cours_redaction' => '​កំពុង តែងអត្ថបទ',
@@ -564,7 +560,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'titre_cadre_raccourcis' => 'ផ្លូវ​កាត់ ៖',
 	'titre_changer_couleur_interface' => 'ផ្លាស់​ប្ដូរ ​ពណ៌ផ្ទាំង​ប្រទាក់',
 	'titre_image_admin_article' => 'អ្នក​អាច​គ្រប់គ្រង​អត្ថបទ​នេះ',
-	'titre_image_administrateur' => 'អ្នកគ្រប់គ្រង',
+	'titre_image_administrateur' => 'អ្នកគ្រប់គ្រង', # MODIF
 	'titre_image_aide' => 'ពីជំនួយ លើធាតុនេះ',
 	'titre_image_auteur_supprime' => 'បានលុបចេញ អ្នកនិពន្ធ',
 	'titre_image_redacteur' => 'អ្នកតែងអត្ថបទ គ្មានការចូលទៅ',
@@ -628,5 +624,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'zxml_survoler' => 'ហោះហើរ ដើម្បីមើល ការត្រឹមត្រូវ',
 	'zxml_valeur_attribut' => 'តំលៃ នៃសេចក្តីកំណត់',
 	'zxml_vide_balise' => 'ប្លាក​ទទេ',
-	'zxml_vu' => 'បានឃើញ ​ពី​មុន'
-);
+	'zxml_vu' => 'បានឃើញ ​ពី​មុន',
+];
