@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=br
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'mediabox_description' => '
@@ -26,5 +22,5 @@ Gant ur panel kefluniadur e c’hallit kemmañ ar penn-dibarzhoù giz ma plij de
 	Ar plugin-se a ya gant skeledennoù oc’h ober gant an arouez
  <code>#INSERT_HEAD</code>',
 	'mediabox_nom' => 'MediaBoest',
-	'mediabox_slogan' => 'Boest liesvedia'
-);
+	'mediabox_slogan' => 'Boest liesvedia',
+];
