@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=en
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'mediabox_description' => 'By default, all links to pictures (with a type attribute describing the mime/type of the picture) and
@@ -22,5 +18,5 @@ A configuration panel lets you edit the general settings to your liking, and the
 
 This plugin works on skeletons which have the <code>#INSERT_HEAD</code> tag.',
 	'mediabox_nom' => 'MediaBox',
-	'mediabox_slogan' => 'Media box'
-);
+	'mediabox_slogan' => 'Media box',
+];
