@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=es
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'mediabox_description' => 'Por defecto, todos los enlaces definidos sobre imágenes (con un atributo tipo que describa el mime/type de la imafen) así como los enlaces con la clase <code>.mediabox</code> son enriquecidos por la caja multimedia.
@@ -24,5 +20,5 @@ Un panel de configuración permite modificar tanto las especificaciones generale
 	
 Este plugin funciona en los esqueletos que incluyen la baliza <code>#INSERT_HEAD</code>',
 	'mediabox_nom' => 'MediaBox',
-	'mediabox_slogan' => 'Caja multimedia'
-);
+	'mediabox_slogan' => 'Caja multimedia',
+];
