@@ -1,11 +1,8 @@
 <?php
 // This is a SPIP language file  --  Ceci est un fichier langue de SPIP
 // Fichier source, a modifier dans https://git.spip.net/spip/mediabox.git
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
 
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'mediabox_description' => 'Par défaut, tous les liens vers des images (avec un attribut type décrivant le mime/type de l’image) ainsi que les liens avec la classe <code>.mediabox</code> sont enrichis par la boîte multimédia.
@@ -22,5 +19,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	
 	Ce plugin fonctionne sur les squelettes disposant de la balise <code>#INSERT_HEAD</code>',
 	'mediabox_nom' => 'MediaBox',
-	'mediabox_slogan' => 'Boîte multimédia'
-);
+	'mediabox_slogan' => 'Boîte multimédia',
+];
