@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=sk
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'mediabox_description' => 'Podľa predvolených nastavení všetky odkazy k obrázkom (s typom v parametre, ktorý uvádza mime/typ obrázka) a odkazy v triede <code>.mediabox</code> obohacuje multimediálny box.
@@ -24,5 +20,5 @@ Ovládací panel vám umožňuje všeobecné nastavenia podľa vašich želaní
 
 Tento zásuvný modul spolupracuje so šablónami, ktoré obsahujú tag <code>#INSERT_HEAD</code>',
 	'mediabox_nom' => 'Multimediálny box',
-	'mediabox_slogan' => 'Multimediálny box'
-);
+	'mediabox_slogan' => 'Multimediálny box',
+];
