@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=uk
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// M
 	'mediabox_description' => 'Зазвичай усі посилання на зображення (файли з відповідним mime/type атрибутом) і посилання з CSS класом <code>.mediabox</code> виводяться у вікні, що спливає.
@@ -23,5 +19,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 В налаштуваннях модуля ви можете змінити зовнішній вигляд блоків та інші налаштування.
 	Модуль працює лише в тому випадку, якщо ви додаєте тег <code>#INSERT_HEAD</code> до ваших шаблонів.',
 	'mediabox_nom' => 'MediaBox',
-	'mediabox_slogan' => 'Медіабокс'
-);
+	'mediabox_slogan' => 'Медіабокс',
+];
