@@ -406,10 +406,12 @@ $tables_mime = [
 $mime_alias = [
 	'application/x-ogg' => 'application/ogg',
 	'audio/3gpp' => 'video/3gpp',
+	'audio/x-m4a' => 'audio/mp4a-latm',
 	'audio/x-mpeg' => 'audio/mpeg',
 	'audio/x-musepack' => 'audio/musepack',
 	'audio/webm' => 'video/webm',
 	'video/flv' => 'video/x-flv',
 	'video/mp4' => 'application/mp4',
-	'image/jpg' => 'image/jpeg'
+	'audio/mp4' => 'application/mp4',
+	'image/jpg' => 'image/jpeg',
 ];
