@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=eo
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'affichage_documents_en_cases' => 'Montri kvadrate',
@@ -53,7 +49,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'des_images' => '@nb@ bildoj',
 	'des_utilisations' => '@nb@ uzoj',
 	'des_videos' => '@nb@ filmoj',
-	'descriptif' => 'Priskribo',
+	'descriptif' => 'Priskribo', # MODIF
 	'details_document' => 'Detaloj',
 	'details_document_afficher_masquer' => 'Montri / kaŝi la detalojn de la dokumento',
 	'document_attache_succes' => 'La dokumento estis aldonita',
@@ -207,5 +203,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// V
 	'verifier_documents_brises' => 'Kontroli, ĉu mankas dosieroj',
 	'verifier_documents_inutilises' => 'Kontroli la ligilojn de la dokumentoj',
-	'vignette_supprimee' => 'La vinjeto estis forigita'
-);
+	'vignette_supprimee' => 'La vinjeto estis forigita',
+];
