@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=ja
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'affichage_documents_en_cases' => 'ボックスで表示',
@@ -53,7 +49,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'des_images' => '画像@nb@枚',
 	'des_utilisations' => '使用は@nb@回',
 	'des_videos' => '動画@nb@本',
-	'descriptif' => '記述',
+	'descriptif' => '記述', # MODIF
 	'details_document' => '詳細',
 	'details_document_afficher_masquer' => 'ドキュメントの詳細を表示／非表示',
 	'document_attache_succes' => 'ドキュメントが追加されています',
@@ -209,5 +205,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// V
 	'verifier_documents_brises' => '見つからないファイルを確認',
 	'verifier_documents_inutilises' => 'ドキュメントへのリンクの確認',
-	'vignette_supprimee' => 'サムネイルが取り除かれた'
-);
+	'vignette_supprimee' => 'サムネイルが取り除かれた',
+];
