@@ -3,11 +3,7 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=nl
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
 	'affichage_documents_en_cases' => 'Weergave in vakjes',
@@ -53,7 +49,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'des_images' => '@nb@ afbeeldingen',
 	'des_utilisations' => '@nb@ toepassingen',
 	'des_videos' => '@nb@ videos',
-	'descriptif' => 'Beschrijving',
+	'descriptif' => 'Beschrijving', # MODIF
 	'details_document' => 'Details',
 	'details_document_afficher_masquer' => 'Toon/verberg de details van het document',
 	'document_attache_succes' => 'Het document werd bijgevoegd',
@@ -208,5 +204,5 @@ tekst opgenomen worden of afzonderlijk worden getoond.',
 	// V
 	'verifier_documents_brises' => 'Ontbrekende bestanden checken',
 	'verifier_documents_inutilises' => 'Links naar documenten checken',
-	'vignette_supprimee' => 'Verkleining wordt verwijderd'
-);
+	'vignette_supprimee' => 'Verkleining wordt verwijderd',
+];
