@@ -3,13 +3,10 @@
 // extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=uk
 // ** ne pas modifier le fichier **
 
-if (!defined('_ECRIRE_INC_VERSION')) {
-	return;
-}
-
-$GLOBALS[$GLOBALS['idx_lang']] = array(
+return [
 
 	// A
+	'affichage_documents_en_cases' => 'Показувати в рамці',
 	'affichage_documents_en_grand' => 'Великий екран',
 	'affichage_documents_en_liste_compacte' => 'Компактні списки',
 	'aucun_audio' => 'Нема аудіо файлів ',
@@ -41,8 +38,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'bouton_remplacer_image' => 'Замінити зображення',
 	'bouton_remplacer_image_document' => 'Замінити зображенням або файлом',
 	'bouton_supprimer' => 'Видалити',
-	'bouton_supprimer_tous_orphelins' => 'Видалити ті, що не використовуються', # MODIF
-	'bouton_supprimer_tous_orphelins_confirmation' => 'Ви дійсно хочете видалити @nb@ документів (файлів)?', # MODIF
+	'bouton_supprimer_tous_orphelins' => 'Видалити всі, що не використовуються',
+	'bouton_supprimer_tous_orphelins_confirmation' => 'Ви дійсно хочете видалити @nb@ файлів?',
 	'bouton_upload' => 'Додати',
 
 	// D
@@ -104,6 +101,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'image_tourner_180' => 'Поворот на 180°',
 	'image_tourner_droite' => 'Поворот на 90° вправо',
 	'image_tourner_gauche' => 'Поворот на 90° вліво',
+	'info_alt' => 'Alt атрибут - текст який виводиться замість зображення, якщо його не вдається відобразити.',
 	'info_dimensions_image' => 'Розміри',
 	'info_doc_max_poids' => 'Розмір файлу має бути не більше @maxi@ (поточний розмір @actuel@).',
 	'info_document' => 'Документ',
@@ -116,6 +114,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_illustrations' => 'Ілюстрації',
 	'info_image_max_poids' => 'Розмір файлу зображення має бути менше @maxi@ (зараз @actuel@).',
 	'info_image_max_taille' => 'Розмір файлу зображення має бути менше @maxi@ (зараз @actuel@).',
+	'info_image_min_taille' => 'Розмір зображення має бути щонайменше @mini@ (наразі розмір файла @actuel@).',
 	'info_inclusion_directe' => 'Пряме включення:',
 	'info_inclusion_vignette' => 'Додати мініатюру:',
 	'info_installer_tous_documents' => 'Додати усі файли (документы)',
@@ -125,17 +124,21 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'info_modifier_document' => 'Змінити файл',
 	'info_portfolio' => 'Галерея фотографій і документів',
 	'info_referencer_doc_distant' => 'Посилання на файл (URL):',
+	'info_resolution_image' => 'Якість',
 	'info_resolution_mpx' => '@resolution@ Mpx',
 	'info_sans_vignette' => 'Без мініатюри',
 	'info_statut_document' => 'Статус документу:',
 	'info_taille' => 'Вага',
 	'info_telecharger' => 'Завантажити з вашого комп’ютера:',
+	'info_utilisation' => 'Використовується',
 	'infos' => 'Технічна інформація',
+	'inserer_raccourci' => 'Додати це скорочення у текст',
 	'item_autoriser_selectionner_date_en_ligne' => 'Дозволити змінювати дату додання документу',
 	'item_non_autoriser_selectionner_date_en_ligne' => 'Заборонити змінювати дату додання документу',
 
 	// L
 	'label_activer_document_objets' => 'Включити галерею:',
+	'label_alt' => 'Опис зображеня (alt)',
 	'label_apercu' => 'Попередній перегляд',
 	'label_caracteristiques' => 'Характеристики',
 	'label_credits' => 'Інформація про автора',
@@ -144,8 +147,11 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	'label_paginer_par' => 'Посторінково по:',
 	'label_parents' => 'Документ використовується в:',
 	'label_refdoc_joindre' => 'Номер документа',
+	'label_titre_mimetype' => 'Тип файлу',
+	'lien_tout_desordonner' => 'Скинути порядок',
 	'lien_tout_desordonner_verif' => 'Порядок, встановлений для цього списку документів, буде скинуто. Ви впевнені?',
-	'lien_tout_enlever' => 'Видалити усе', # MODIF
+	'lien_tout_enlever' => 'Видалити все',
+	'lien_tout_enlever_verif' => 'Ви дійсно хочете від’єднати всі документи?',
 	'logo' => 'Лого',
 
 	// M
@@ -203,5 +209,5 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 	// V
 	'verifier_documents_brises' => 'Перевірити відсутні файли',
 	'verifier_documents_inutilises' => 'Перевірити використання документу',
-	'vignette_supprimee' => 'Мініатюру видалено'
-);
+	'vignette_supprimee' => 'Мініатюру видалено',
+];
