@@ -11,7 +11,8 @@
 
 // Script pour appeler un squelette apres s'etre authentifie
 
-include_once 'inc_version.php';
+require_once __DIR__ . '/../vendor/autoload.php';
+include_once __DIR__ . '/inc_version.php';
 
 include_spip('inc/cookie');
 
