@@ -40,12 +40,11 @@ function generer_nom_fichier_cache($contexte, $page) {
  * Attention a modifier simultanement le sanity check de
  * la fonction retire_cache() de inc/invalideur
  *
- * @param $nom_cache
  * @return string
  */
 function cache_chemin_fichier($nom_cache, $ecrire = false) {
 	static $l1, $l2;
-	if (is_null($l1)) {
+	if ($l1 === null) {
 		$length = (defined('_CACHE_PROFONDEUR_STOCKAGE') ? min(8, max(_CACHE_PROFONDEUR_STOCKAGE, 2)) : 4);
 		$l1 = intval(floor($length / 2));
 		$l2 = $length - $l1;
@@ -57,8 +56,7 @@ function cache_chemin_fichier($nom_cache, $ecrire = false) {
 		$rep = sous_repertoire(_DIR_CACHE, '', false, true);
 		$rep = sous_repertoire($rep, 'calcul/', false, true);
 		$rep = sous_repertoire($rep, $d, false, true);
-	}
-	else {
+	} else {
 		// en lecture on essaye pas de creer les repertoires, on va au plus vite
 		$rep = _DIR_CACHE . "calcul/$d/";
 	}
@@ -70,11 +68,13 @@ function cache_chemin_fichier($nom_cache, $ecrire = false) {
  * ecrire le cache dans un casier
  *
  * @param string $nom_cache
- * @param $valeur
  * @return bool
  */
 function ecrire_cache($nom_cache, $valeur) {
-	return ecrire_fichier(cache_chemin_fichier($nom_cache, true), serialize(['nom_cache' => $nom_cache, 'valeur' => $valeur]));
+	return ecrire_fichier(
+		cache_chemin_fichier($nom_cache, true),
+		serialize(['nom_cache' => $nom_cache, 'valeur' => $valeur])
+	);
 }
 
 /**
@@ -98,6 +98,10 @@ function lire_cache($nom_cache) {
 	return false;
 }
 
+function supprime_fichier_cache($nom_cache) {
+	return supprimer_fichier(cache_chemin_fichier($nom_cache));
+}
+
 // Parano : on signe le cache, afin d'interdire un hack d'injection
 // dans notre memcache
 function cache_signature(&$page) {
@@ -106,11 +110,7 @@ function cache_signature(&$page) {
 		include_spip('auth/sha256.inc');
 		ecrire_meta(
 			'cache_signature',
-			spip_sha256(
-				$_SERVER['DOCUMENT_ROOT']
-				. ($_SERVER['SERVER_SIGNATURE'] ?? '')
-				. creer_uniqid()
-			),
+			spip_sha256($_SERVER['DOCUMENT_ROOT'] . ($_SERVER['SERVER_SIGNATURE'] ?? '') . creer_uniqid()),
 			'non'
 		);
 	}
@@ -145,7 +145,6 @@ function gzip_page($page) {
  * de decompresser deux fois de suite un cache (ce qui echoue)
  *
  * @param array $page
- * @return void
  */
 function gunzip_page(&$page) {
 	if ($page['gz']) {
@@ -219,19 +218,18 @@ function cache_valide(&$page, $date) {
 	$duree = (int) $page['entetes']['X-Spip-Cache'];
 	$cache_mark = max($GLOBALS['meta']['cache_mark'] ?? 0, $GLOBALS['meta']['cache_bot_invalide'] ?? 0);
 	if ($duree == 0) {  #CACHE{0}
-	return -1;
+		return -1;
 	} // sauf pour les bots, qui utilisent toujours le cache
-	else {
-		if (
-			(!_IS_BOT and $date + $duree < $now)
-			# le cache est anterieur a la derniere purge : l'ignorer, meme pour les bots
-			or $date < $cache_mark
-		) {
-			return _IS_BOT ? -1 : 1;
-		} else {
-			return 0;
-		}
+
+	if (
+		(!_IS_BOT and $date + $duree < $now)
+		# le cache est anterieur a la derniere purge : l'ignorer, meme pour les bots
+		or $date < $cache_mark
+	) {
+		return _IS_BOT ? -1 : 1;
 	}
+	return 0;
+
 }
 
 /**
@@ -240,7 +238,6 @@ function cache_valide(&$page, $date) {
  *
  * @param array $page
  * @param string $chemin_cache
- * @return void
  */
 function creer_cache(&$page, &$chemin_cache) {
 
@@ -268,7 +265,7 @@ function creer_cache(&$page, &$chemin_cache) {
 			spip_log('Creation cache sessionne ' . $chemin_cache);
 			$tmp = [
 				'invalideurs' => ['session' => ''],
-				'lastmodified' => $_SERVER['REQUEST_TIME']
+				'lastmodified' => $_SERVER['REQUEST_TIME'],
 			];
 			ecrire_cache($chemin_cache, $tmp);
 		}
@@ -299,28 +296,25 @@ function creer_cache(&$page, &$chemin_cache) {
 	maj_invalideurs($chemin_cache, $page);
 }
 
-
 /**
  * purger un petit cache (tidy ou recherche) qui ne doit pas contenir de
  * vieux fichiers ; (cette fonction ne sert que dans des plugins obsoletes)
  *
  * @param string $prefix
  * @param int $duree
- * @return void
  */
 function nettoyer_petit_cache($prefix, $duree = 300) {
 	// determiner le repertoire a purger : 'tmp/CACHE/rech/'
 	$dircache = sous_repertoire(_DIR_CACHE, $prefix);
 	if (spip_touch($dircache . 'purger_' . $prefix, $duree, true)) {
 		foreach (preg_files($dircache, '[.]txt$') as $f) {
-			if ($_SERVER['REQUEST_TIME'] - (@file_exists($f) ? @filemtime($f) : 0) > $duree) {
+			if ($duree < $_SERVER['REQUEST_TIME'] - (@file_exists($f) ? @filemtime($f) : 0)) {
 				spip_unlink($f);
 			}
 		}
 	}
 }
 
-
 /**
  * Interface du gestionnaire de cache
  * Si son 3e argument est non vide, elle passe la main a creer_cache
@@ -398,16 +392,15 @@ function public_cacher_dist($contexte, &$use_cache, &$chemin_cache, &$page, &$la
 		}
 	}
 
-
 	// Faut-il effacer des pages invalidees (en particulier ce cache-ci) ?
 	if (isset($GLOBALS['meta']['invalider'])) {
 		// ne le faire que si la base est disponible
 		if (spip_connect()) {
 			include_spip('inc/invalideur');
 			retire_caches($chemin_cache); # API invalideur inutile
-			supprimer_fichier(_DIR_CACHE . $chemin_cache);
+			supprime_fichier_cache($chemin_cache);
 			if (isset($chemin_cache_session) and $chemin_cache_session) {
-				supprimer_fichier(_DIR_CACHE . $chemin_cache_session);
+				supprime_fichier_cache($chemin_cache_session);
 			}
 		}
 	}
@@ -424,9 +417,9 @@ function public_cacher_dist($contexte, &$use_cache, &$chemin_cache, &$page, &$la
 		$page = ['contexte_implicite' => $contexte_implicite]; // ignorer le cache deja lu
 		include_spip('inc/invalideur');
 		retire_caches($chemin_cache); # API invalideur inutile
-		supprimer_fichier(_DIR_CACHE . $chemin_cache);
+		supprime_fichier_cache($chemin_cache);
 		if (isset($chemin_cache_session) and $chemin_cache_session) {
-			supprimer_fichier(_DIR_CACHE . $chemin_cache_session);
+			supprime_fichier_cache($chemin_cache_session);
 		}
 	}
 
