@@ -90,7 +90,7 @@ function public_debusquer_dist($message = '', $lieu = '', $opt = []) {
 		set_request('var_mode', 'debug');
 		$GLOBALS['bouton_admin_debug'] = true;
 		// Permettre a la compil de continuer
-		if (is_object($lieu) and (!isset($lieu->code) or !$lieu->code)) {
+		if (is_object($lieu) && property_exists($lieu, 'code') && !$lieu->code) {
 			$lieu->code = "''";
 		}
 		// loger
@@ -356,26 +356,26 @@ function debusquer_requete($message) {
 	}
 
 	// Erreur systeme
-	if (is_numeric($errno) and $errno > 0 and $errno < 200) {
-		$retour = '<tt><br><br><blink>'
+	if (is_numeric($errno) && $errno > 0 && $errno < 200) {
+		$retour = '<code><br><br>'
 			. _T('info_erreur_systeme', ['errsys' => $errno])
-			. "</blink><br>\n<b>"
+			. "<br>\n<b>"
 			. _T(
 				'info_erreur_systeme2',
 				['script' => generer_url_ecrire('base_repair')]
 			)
-			. '</b><br>';
+			. '</b></code><br>';
 		spip_log("Erreur systeme $errno");
 
 		return [$retour, ''];
 	}
 
 	// Requete erronee
-	$err = '<b>' . _T('avis_erreur_mysql') . " $errno</b><br><tt>\n"
+	$err = '<b>' . _T('avis_erreur_mysql') . " $errno</b><br><code>\n"
 		. spip_htmlspecialchars($msg)
 		. "\n<br><span style='color: red'><b>"
 		. spip_htmlspecialchars($query)
-		. '</b></span></tt><br>';
+		. '</b></span></code><br>';
 
 	//. aider('erreur_mysql');
 
