@@ -385,7 +385,7 @@ function quete_logo($cle_objet, $onoff, $id, $id_rubrique, $flag = false) {
 				$res['logo_off'] = $res[1];
 				$res['width'] = ($taille ? $taille[0] : '');
 				$res['height'] = ($taille ? $taille[1] : '');
-				$res['fichier'] = $on['fichier'];
+				$res['fichier'] = ($on['fichier'] ?? '');
 				$res['titre'] = ($on['titre'] ?? '');
 				$res['descriptif'] = ($on['descriptif'] ?? '');
 				$res['credits'] = ($on['credits'] ?? '');
@@ -482,7 +482,7 @@ function quete_logo_file($row, $connect = null) {
 	}
 	if (!$logo) {
 		$f = charger_fonction('vignette', 'inc');
-		$logo = $f($row['extension'], false);
+		$logo = $f($row['extension'], $row['media']);
 	}
 	// si c'est une vignette type doc, la renvoyer direct
 	if (
