@@ -7,7 +7,6 @@
  *  Arnaud Martin, Antoine Pitrou, Philippe Rivière, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.     *
- *  Pour plus de détails voir le fichier COPYING.txt ou l'aide en ligne.   *
 \***************************************************************************/
 
 if (!defined('_ECRIRE_INC_VERSION')) {
@@ -20,7 +19,15 @@ include_spip('req/sqlite_generique');
 $GLOBALS['spip_sqlite3_functions_1'] = _sqlite_ref_fonctions();
 
 
-function req_sqlite3_dist($addr, $port, $login, $pass, $db = '', $prefixe = '') {
+function req_sqlite3_dist(
+	$addr,
+	$port,
+	$login,
+	#[\SensitiveParameter]
+	$pass,
+	$db = '',
+	$prefixe = ''
+) {
 	return req_sqlite_dist($addr, $port, $login, $pass, $db, $prefixe, $sqlite_version = 3);
 }
 
