@@ -61,14 +61,14 @@ abstract class AbstractPage {
 		}
 		http_no_cache();
 
-		$page_title = (isset($options['page_title']) ? $options['page_title'] : $GLOBALS['meta']['nom_site']);
-		$doctype = (isset($options['doctype']) ? $options['doctype'] : "<!DOCTYPE html>");
-		$doctype = trim($doctype) . "\n";
-		$charset = (isset($options['charset']) ? $options['charset'] : "utf-8");
-		$all_inline = (isset($options['all_inline']) ? $options['all_inline'] : true);
-		$onLoad = ($options['onload'] ?? '');
-		if ($onLoad) {
-			$onLoad = ' onload="' . attribut_html($onLoad) . '"';
+		$page_title = ($options['page_title'] ?? $GLOBALS['meta']['nom_site']);
+		$doctype = ($options['doctype'] ?? '<!DOCTYPE html>');
+		$doctype = trim((string) $doctype) . "\n";
+		$charset = ($options['charset'] ?? 'utf-8');
+		$all_inline = ($options['all_inline'] ?? true);
+		$onload = ($options['onload'] ?? '');
+		if ($onload) {
+			$onload = ' onload="' . attribut_html($onload) . '"';
 		}
 
 		# envoyer le charset
@@ -145,7 +145,7 @@ abstract class AbstractPage {
 			$css .
 			(empty($options['head']) ? "" : $options['head']) .
 			"</head>\n" .
-			"<body{$onLoad} class=\"minipage" . ($this::TYPE ? ' minipage--' . $this::TYPE : '') . "\">\n" .
+			"<body{$onload} class=\"minipage" . ($this::TYPE ? ' minipage--' . $this::TYPE : '') . "\">\n" .
 			"\t<div class=\"minipage-bloc\">\n";
 	}
 
